::  DB2 9.7 Admin for Experienced DBAs
::  Copyright(r) IBM Corporation
::
::  Burt Vialpando (burt.vialpando@us.ibm.com)
::  Vikram Khatri (vikram.khatri@us.ibm.com)
::

REM ---------------------------------------------------------------------
REM WARNING: YOU DO NOT NEED TO RUN THIS SCRIPT IF YOU ARE USING THE 
REM          VMWARE IMAGE BECAUSE THIS SCRIPT HAS BEEN RUN ALREADY ON IT.
REM
REM          For this script to run properly, You MUST be logged in as 
REM          DBAPOT and have adminstrator rights to your machine.
REM
REM ---------------------------------------------------------------------
REM          This script will perform the following things:
REM          1. Create users: db2user1, db2user2   - passwords same as name
REM             Create users: db2cobra, db2default - passwords same as name
REM          2. Set compatability vector to FFF
REM          3. Drop and recreate the SAMPLE database
REM          4. Drop and recreate the GSDB database
REM          5. Set Windows file associations used in the labs
REM ---------------------------------------------------------------------
REM  

TITLE SETUP01.BAT - This script sets up the POT labs environment

SET OUTFILE=%~n0_OUTPUT.TXT

@echo off
cls
@echo.
@echo WARNING!  THIS SCRIPT IS ABOUT TO DROP AND RECREATE THE SAMPLE
@echo           DATABASE AND CREATE USERIDS ON YOUR SYSTEM!!!
@echo.
@echo           You do NOT need to run this script if you are using the
@echo           VM ware image for these labs.
@echo.
@echo           For this script to run properly you must be:
@echo           1) logged into Windows as USER dbapot PASSWORD dbapot123
@echo           2) dbapot must have administrator rights to your machine
@echo.

@echo off
cls

@ECHO.
@ECHO --------------------------------------------------------------------
@ECHO By: %USERNAME%  %DATE% Machine: %COMPUTERNAME% ON %OS%
ECHO ---------------------------------------------------------------------
@ECHO.

@echo * =============================================================== *
@echo * 1. Delete and recreate Users 
@echo * =============================================================== *
@echo .

call :DropUser db2cobra
call :DropUser db2user1
call :DropUser db2user2
call :DropUser db2default

call :CreateUser db2cobra
call :CreateUser db2user1
call :CreateUser db2user2
call :CreateUser db2default




@echo * =============================================================== *
@echo * 2. The db2 compatibility vector and other environment settings
@echo * =============================================================== *
@echo .

db2 terminate
set db2instance=db2
db2set db2comm=TCPIP
db2set db2_compatibility_vector=FFF
db2set DB2_SQLROUTINE_PREPOPTS=
db2set db2instdef=DB2
db2 update dbm cfg using SVCENAME 50000
db2 get instance
db2stop force

del "C:\Documents and Settings\All Users\Application Data\IBM\DB2\DB2COPY1\DB2\db2diag.log" /s/q/f > NUL

db2start

db2set -all




@echo .
@echo * =============================================================== *
@echo * 3. Recreating the SAMPLE database (with Oracle compatibility)
@echo * =============================================================== *
@echo .

db2sampl -force -sql -xml -quiet

db2 connect to sample

DB2 GRANT DBADM,ACCESSCTRL,DATAACCESS,WLMADM,SQLADM,CREATETAB,BINDADD,CONNECT,CREATE_NOT_FENCED_ROUTINE,IMPLICIT_SCHEMA,LOAD,CREATE_EXTERNAL_ROUTINE,QUIESCE_CONNECT,SECADM ON DATABASE  TO USER DB2USER1
DB2 GRANT DBADM,ACCESSCTRL,DATAACCESS,WLMADM,SQLADM,CREATETAB,BINDADD,CONNECT,CREATE_NOT_FENCED_ROUTINE,IMPLICIT_SCHEMA,LOAD,CREATE_EXTERNAL_ROUTINE,QUIESCE_CONNECT,SECADM ON DATABASE  TO USER DB2USER2
DB2 GRANT DBADM,ACCESSCTRL,DATAACCESS,WLMADM,SQLADM,CREATETAB,BINDADD,CONNECT,CREATE_NOT_FENCED_ROUTINE,IMPLICIT_SCHEMA,LOAD,CREATE_EXTERNAL_ROUTINE,QUIESCE_CONNECT,SECADM ON DATABASE  TO USER DB2DEFAULT
DB2 GRANT DBADM,ACCESSCTRL,DATAACCESS,WLMADM,SQLADM,CREATETAB,BINDADD,CONNECT,CREATE_NOT_FENCED_ROUTINE,IMPLICIT_SCHEMA,LOAD,CREATE_EXTERNAL_ROUTINE,QUIESCE_CONNECT,SECADM ON DATABASE  TO USER DB2COBRA


@echo .
@echo * =============================================================== *
@echo * 4. create the GSDB (Great Outdoors) Database 
@echo *    (without Oracle compatibility)
@echo * =============================================================== *
@echo .

db2 terminate
set db2instance=db2
db2set db2_compatibility_vector=
db2 get instance
db2stop force
db2start

db2set -all

DB2 DROP DATABASE GSDB

db2 -tvf C:\POT_DB2\00SETUP\Setup02.sql 
db2 -tvf C:\POT_DB2\00SETUP\Setup03.sql 



@echo .
@echo * =============================================================== *
@echo * 5. Set Windows file associations
@echo * =============================================================== *
@echo .

ASSOC .db2=txtfile
ASSOC .sql=txtfile
ASSOC .ddl=txtfile
ASSOC .dml=txtfile
ASSOC .txt=txtfile
ASSOC .rpt=wordpad

db2 list db directory

@echo .
@echo * =============================================================== *
@echo * End of master setup script
@echo * =============================================================== *
@echo .

GOTO :EOF

:DropUser
setlocal
REM Drop user
net user %1  2>NUL > NUL
IF %ERRORLEVEL% EQU 2 (
   ECHO CREATING USER %1
   NET USER /DELETE %1 2>NUL > NUL
) ELSE (
   ECHO User %1 does not exist
)
ECHO.
endlocal

:CreateUser
setlocal
REM Create user if it does not exist
net user %1  2>NUL > NUL
IF %ERRORLEVEL% EQU 2 (
   ECHO CREATING USER %1
   NET USER /ADD %1 %1 /EXPIRES:NEVER 2>NUL > NUL
   NET LOCALGROUP ADMINISTRATORS %1 /ADD 2>NUL > NUL
) ELSE (
   ECHO User %1 already exists
)
ECHO.
endlocal