--#SET TERMINATOR @

DROP DATABASE GSDB
@

------------------------------------------------
-- CREATE DATABASE GSDB
------------------------------------------------

CREATE DATABASE GSDB  USING CODESET UTF-8 TERRITORY US PAGESIZE 32 K WITH "Version 1.2 12/19/2008"
@

CONNECT TO GSDB
@

SET CURRENT SCHEMA = 'GOSALES'
@

CREATE TABLESPACE GOSALESTBLSPC MANAGED BY AUTOMATIC STORAGE
@

------------------------------------------------
-- CREATE TABLES FOR GOSALES SCHEMA
------------------------------------------------

CREATE TABLE PRODUCT (
		PRODUCT_NUMBER INTEGER NOT NULL,
		BASE_PRODUCT_NUMBER INTEGER,
		INTRODUCTION_DATE TIMESTAMP,
		DISCONTINUED_DATE TIMESTAMP,
		PRODUCT_TYPE_CODE INTEGER NOT NULL,
		PRODUCT_COLOR_CODE INTEGER,
		PRODUCT_SIZE_CODE INTEGER,
		PRODUCT_BRAND_CODE INTEGER,
		PRODUCTION_COST DECIMAL(19 , 2),
		GROSS_MARGIN DOUBLE,
		PRODUCT_IMAGE VARCHAR(50)
	)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@

COMMENT ON TABLE PRODUCT
	IS 'These are all the products Great Outdoor carries'
@

ALTER TABLE PRODUCT ADD CONSTRAINT PRODUCT_NUMBER_PK PRIMARY KEY
	(PRODUCT_NUMBER)
@
	
CREATE TABLE PRODUCT_BRAND (
		PRODUCT_BRAND_CODE INTEGER NOT NULL,
		PRODUCT_BRAND_EN VARCHAR(50)
	)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@

COMMENT ON TABLE PRODUCT_BRAND
	IS 'These are all the product brands associated with product table.'
@
  
ALTER TABLE PRODUCT_BRAND ADD CONSTRAINT PRODUCT_BRAND_CODE_PK PRIMARY KEY
	(PRODUCT_BRAND_CODE)
@

CREATE TABLE PRODUCT_COLOR_LOOKUP (
		PRODUCT_COLOR_CODE INTEGER NOT NULL,
		PRODUCT_COLOR_EN VARCHAR(50)
	)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@

COMMENT ON TABLE PRODUCT_COLOR_LOOKUP
	IS 'This is the lookup table for product colors.'
@

ALTER TABLE PRODUCT_COLOR_LOOKUP ADD CONSTRAINT PRODUCT_COLOR_CODE_PK PRIMARY KEY
	(PRODUCT_COLOR_CODE)
@

CREATE TABLE PRODUCT_FORECAST (
		SALES_YEAR INTEGER NOT NULL,
		SALES_MONTH INTEGER NOT NULL,
		BRANCH_CODE INTEGER NOT NULL,
		BASE_PRODUCT_NUMBER INTEGER NOT NULL,
		UNIT_COST DECIMAL(19 , 2),
		UNIT_PRICE DECIMAL(19 , 2),
		EXPECTED_VOLUME INTEGER
	)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@

COMMENT ON TABLE PRODUCT_FORECAST
	IS 'Sales forecast for products in the years 2004, 2005, 2006, 2007'
@

ALTER TABLE PRODUCT_FORECAST ADD CONSTRAINT PRODUCT_FORECAST_PK PRIMARY KEY
	(SALES_YEAR,
	 SALES_MONTH,
	 BRANCH_CODE,
	 BASE_PRODUCT_NUMBER)
@


CREATE TABLE PRODUCT_LINE (
		PRODUCT_LINE_CODE INTEGER NOT NULL,
		PRODUCT_LINE_EN VARCHAR(40) NOT NULL
	)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@
	
COMMENT ON TABLE PRODUCT_LINE
	IS 'Different lines of products carried'
@

CREATE INDEX PRODUCT_LINE_IX
	ON PRODUCT_LINE
	(PRODUCT_LINE_EN ASC) PCTFREE 10
@

ALTER TABLE PRODUCT_LINE ADD CONSTRAINT PRODUCT_LINE_CODE_PK PRIMARY KEY
	(PRODUCT_LINE_CODE)
@
	
CREATE TABLE PRODUCT_NAME_LOOKUP (
		PRODUCT_NUMBER INTEGER NOT NULL,
		PRODUCT_LANGUAGE VARCHAR(2) NOT NULL,
		PRODUCT_NAME VARCHAR(50),
		PRODUCT_DESCRIPTION VARCHAR(255)
	)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@
	
COMMENT ON TABLE PRODUCT_NAME_LOOKUP
	IS 'Names of the products carried'
@

CREATE INDEX PRODUCT_NAME_IX
	ON PRODUCT_NAME_LOOKUP
	(PRODUCT_NAME		ASC) PCTFREE 10
@

ALTER TABLE PRODUCT_NAME_LOOKUP ADD CONSTRAINT PRODUCT_NAME_LOOKUP_PK PRIMARY KEY
	(PRODUCT_NUMBER,
	 PRODUCT_LANGUAGE)
@
	 
CREATE TABLE PRODUCT_SIZE_LOOKUP (
		PRODUCT_SIZE_CODE INTEGER NOT NULL,
		PRODUCT_SIZE_EN VARCHAR(50)
	)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@
	
COMMENT ON TABLE PRODUCT_SIZE_LOOKUP
	IS 'Different sizes associated with the products'
@

ALTER TABLE PRODUCT_SIZE_LOOKUP ADD CONSTRAINT PRODUCT_SIZE_CODE_PK PRIMARY KEY
	(PRODUCT_SIZE_CODE)
@
	
CREATE TABLE PRODUCT_TYPE (
		PRODUCT_TYPE_CODE INTEGER NOT NULL,
		PRODUCT_LINE_CODE INTEGER NOT NULL,
		PRODUCT_TYPE_EN VARCHAR(50) NOT NULL
	)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@

COMMENT ON TABLE PRODUCT_TYPE
	IS 'Different types of products carried.  Sorted by product types.'
@

CREATE INDEX PRODUCT_LINE_CODE_IX
	ON PRODUCT_TYPE
	(PRODUCT_LINE_CODE		ASC) PCTFREE 10
@

CREATE INDEX PRODUCT_TYPE_EN_IX
	ON PRODUCT_TYPE
	(PRODUCT_TYPE_EN		ASC) PCTFREE 10
@

ALTER TABLE PRODUCT_TYPE ADD CONSTRAINT PRODUCT_TYPE_CODE_PK PRIMARY KEY
	(PRODUCT_TYPE_CODE)
@
	
CREATE TABLE ORDER_METHOD
(
  ORDER_METHOD_CODE INTEGER NOT NULL,
  ORDER_METHOD_EN VARCHAR(50)
)
DATA CAPTURE NONE
CCSID UNICODE
IN GOSALESTBLSPC
@

COMMENT ON TABLE ORDER_METHOD
	IS 'Different methods of ordering Great Outdoors supports.'
@
	
ALTER TABLE ORDER_METHOD ADD CONSTRAINT ORDER_METHOD_CODE_PK PRIMARY KEY (ORDER_METHOD_CODE)
@

CREATE TABLE INVENTORY_LEVELS (
		INVENTORY_YEAR SMALLINT NOT NULL,
		INVENTORY_MONTH SMALLINT NOT NULL,
		WAREHOUSE_BRANCH_CODE INTEGER NOT NULL,
		PRODUCT_NUMBER INTEGER NOT NULL,
		OPENING_INVENTORY INTEGER,
		QUANTITY_SHIPPED INTEGER,
		ADDITIONS INTEGER,
		UNIT_COST DECIMAL(19 , 2),
		CLOSING_INVENTORY INTEGER NOT NULL,
		AVERAGE_UNIT_COST DECIMAL(19 , 2)
	)
DATA CAPTURE NONE
CCSID UNICODE
IN GOSALESTBLSPC
@

COMMENT ON TABLE INVENTORY_LEVELS
	IS 'Inventory level for years: 2004, 2005, 2006, 2007.'
@

ALTER TABLE INVENTORY_LEVELS ADD CONSTRAINT INVENTORY_LEVELS_PK PRIMARY KEY
	(INVENTORY_YEAR,
	 INVENTORY_MONTH,
	 WAREHOUSE_BRANCH_CODE,
	 PRODUCT_NUMBER)
@

SET CURRENT SCHEMA = 'GOSALESCT'
@

------------------------------------------------
-- CREATE TABLES FOR GOSALESCT SCHEMA
------------------------------------------------

CREATE TABLE PTNR_CNTCT (
		PTNR_CODE INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH 5000, INCREMENT BY 1),
		PTNR_CO_NAME VARCHAR(128) NOT NULL,
		PTNR_FRST_NAME VARCHAR(128),
		PTNR_LAST_NAME VARCHAR(128),
		PTNR_ADDR1 VARCHAR(128),
		PTNR_PROV_STATE VARCHAR(25),
		PTNR_POST_ZONE VARCHAR(100),
		PTNR_CTRY_CODE VARCHAR(25),
		PTNR_CITY VARCHAR(128)
	) 
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@
	
COMMENT ON TABLE PTNR_CNTCT
	IS 'This is to hold our partner information.  We want to expand our company so we have partners sell our products. The partner is like portal that sells our products on their webpages.'
@

CREATE TABLE PTNR_ACTY (
		PTNR_CODE INTEGER NOT NULL,
		ORD_NBR INTEGER NOT NULL,
		PTNR_INV XML,
		CUST_CODE INTEGER NOT NULL,
		PTNR_CUST_CODE VARCHAR(10)
	) 
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@

COMMENT ON TABLE PTNR_ACTY
	IS 'The sales transaction of the partners go into the ptnr_actvy table.  That way when customers call support, we are able to track down their orders.'
@

CREATE TABLE CUST_ORD_DETL(
		ORD_DETL_CODE INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH 1000, INCREMENT BY 1),
		ORD_NBR INTEGER NOT NULL,
		ORD_SHIP_DATE DATE,
		PROD_NBR INTEGER,
		PROD_PROM_CODE INTEGER,
		PROD_QTY INTEGER,
		PROD_UNIT_COST DECIMAL(19 , 2),
		PROD_UNIT_PRC DECIMAL(19 , 2),
		PROD_UNIT_SALE_PRC DECIMAL(19 , 2)
	)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@

COMMENT ON TABLE CUST_ORD_DETL
	IS 'This is used to stored the customer order details. so there could be many of the same order id. i.e. in the customer order they  can have 2 pans, 2 pots and 3 cases but it all belongs in the same order.'
@
	
COMMENT ON COLUMN CUST_ORD_DETL.ORD_DETL_CODE
	IS 'Items that are in each order has one unique order detail code, but only one order number associated with it.'
@

CREATE TABLE CUST_ORD (
		ORD_NBR INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH 100000, INCREMENT BY 1),
		ORD_DATE DATE,
		ORD_NBR_OF_ITEMS INTEGER,
		ORD_NBR_OF_PRODS INTEGER,
		ORD_STOT_COST DECIMAL(30 , 2),
		ORD_SHIP_COST DECIMAL(30 , 2),
		ORD_TAX_COST DECIMAL(30 , 2),
		ORD_TOT_COST DECIMAL(30 , 2),
		ORD_PYMT_METH VARCHAR(128),
		ORD_STAT VARCHAR(128),
		ORD_METH_CODE INTEGER NOT NULL,
		CUST_CRDTCRD_ID INTEGER NOT NULL,
		CUST_CODE INTEGER NOT NULL
	) 
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@
	
COMMENT ON TABLE CUST_ORD
	IS 'This used to stored the customers order, so customers with one order has one order id. this is also for totaling the sales.  i.e many of the same customer id can be in this table, as a customer can have many orders'
@

CREATE TABLE CUST (
		CUST_CODE INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH 100, INCREMENT BY 1),
		CUST_FRST_NAME VARCHAR(128),
		CUST_LAST_NAME VARCHAR(128),
		CUST_ADDR1 VARCHAR(128),
		CUST_CITY VARCHAR(128),
		CUST_POST_ZONE VARCHAR(100),
		CUST_CTRY_CODE VARCHAR(5),
		CUST_PHN_NBR VARCHAR(120),
		CUST_INFO CLOB(32768),
		CUST_EMAIL VARCHAR(128),
		CUST_GNDR_CODE DECIMAL(3 , 0),
		CUST_PROV_STATE VARCHAR(3)
	)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@
	
COMMENT ON TABLE CUST
	IS 'this table is used to stored the customer information and has a CLOB table to consolidated all their information into a XML (stored as a clob since not all customers have XML or XML types.)'
@

CREATE TABLE CUST_CRDTCRD (
		CRDTCRD_ID INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH 200, INCREMENT BY 1),
		CUST_CODE INTEGER NOT NULL,
		CRDTCRD_PRIM_ACCT_NBR CHAR(19),
		CRDTCRD_SERV_CODE INTEGER,
		CRDTCRD_EXP_DATE DATE
	)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@

COMMENT ON TABLE CUST_CRDTCRD
	IS 'Customers can pay for their purchases via credit card. This is table is stored according to credit card industry standards to store credit card information.  '
@

CREATE TABLE CUST_INV (
		ORD_NBR INTEGER NOT NULL,
		ORD_INV XML,
		CUST_CODE INTEGER NOT NULL
	)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@

COMMENT ON TABLE CUST_INV
	IS 'Customer invoice table has xml type to help with collecting the purchase information along with the sales information. it is used as a history for customer sales rep to look up the information.'
@

CREATE TABLE CUST_STATE_TAX (
		CUST_PROV_STATE VARCHAR(3) NOT NULL,
		CUST_TAX_RATE DECIMAL(30 , 2)
	)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@

COMMENT ON TABLE CUST_STATE_TAX
	IS 'Tax rates based on customers residence and used to calculate the tax rate for each sales. '
@
	
CREATE TABLE CUST_CRDT_CHK(
		CUST_CODE INTEGER NOT NULL,
		CUST_SSN BIGINT NOT NULL,
		CRDT_SCR INTEGER)
	DATA CAPTURE NONE 
   IN GOSALESTBLSPC
@

COMMENT ON TABLE CUST_CRDT_CHK
	IS 'Great Outdoors wants to generate more revenue by giving customers credit cards.  they need to do a credit check on their customers prior to issuing the credit cards.  this table is to store that credit information'
@

ALTER TABLE PTNR_ACTY ADD CONSTRAINT PTNR_ACTY_PK PRIMARY KEY (ORD_NBR, PTNR_CODE, CUST_CODE)
@

ALTER TABLE PTNR_CNTCT ADD CONSTRAINT PTNR_CNTCT_PK PRIMARY KEY (PTNR_CODE)
@

ALTER TABLE CUST_CRDT_CHK ADD CONSTRAINT CUST_CRDT_CHK PRIMARY KEY (CUST_CODE)
@

ALTER TABLE CUST_ORD ADD CONSTRAINT CUST_ORD_PK PRIMARY KEY (ORD_NBR)
@

ALTER TABLE CUST ADD CONSTRAINT CUST_PK PRIMARY KEY (CUST_CODE)
@

ALTER TABLE CUST_CRDTCRD ADD CONSTRAINT CUST_CRDTCRD_PK PRIMARY KEY (CRDTCRD_ID, CUST_CODE)
@

ALTER TABLE CUST_STATE_TAX ADD CONSTRAINT CUST_STATE_TAX_PK PRIMARY KEY (CUST_PROV_STATE)
@

ALTER TABLE CUST_ORD_DETL ADD CONSTRAINT CUST_ORD_DETL_PK PRIMARY KEY (ORD_NBR, ORD_DETL_CODE)
@

ALTER TABLE CUST_INV ADD CONSTRAINT CUST_INV_PK PRIMARY KEY (ORD_NBR)
@

ALTER TABLE GOSALESCT.CUST_CRDT_CHK ADD CONSTRAINT CUST_CRDT_CHK_FK FOREIGN KEY(CUST_CODE)
	REFERENCES GOSALESCT.CUST (CUST_CODE)
@

ALTER TABLE GOSALESCT.PTNR_ACTY ADD CONSTRAINT PTNR_ACTY_CUST_FK FOREIGN KEY (CUST_CODE)
	REFERENCES GOSALESCT.CUST (CUST_CODE)
@

ALTER TABLE GOSALESCT.PTNR_ACTY ADD CONSTRAINT PTNR_ACTY_CUST_ORD_FK FOREIGN KEY (ORD_NBR)
	REFERENCES GOSALESCT.CUST_ORD (ORD_NBR)
@
	
ALTER TABLE GOSALESCT.PTNR_ACTY ADD CONSTRAINT PTNR_CNTCT_FK FOREIGN KEY (PTNR_CODE)
	REFERENCES GOSALESCT.PTNR_CNTCT (PTNR_CODE)
@

ALTER TABLE GOSALESCT.CUST_ORD ADD CONSTRAINT CUST_ORD_CUST_FK FOREIGN KEY (CUST_CODE)
	REFERENCES GOSALESCT.CUST (CUST_CODE)
	ON DELETE RESTRICT
@

ALTER TABLE GOSALESCT.CUST_ORD ADD CONSTRAINT CUST_ORD_CUST_CRDTCRD_FK FOREIGN KEY (CUST_CRDTCRD_ID, CUST_CODE)
	REFERENCES GOSALESCT.CUST_CRDTCRD (CRDTCRD_ID, CUST_CODE)
@

ALTER TABLE GOSALESCT.CUST ADD CONSTRAINT CUST_CUST_STATE_TAX_FK FOREIGN KEY (CUST_PROV_STATE)
	REFERENCES GOSALESCT.CUST_STATE_TAX (CUST_PROV_STATE)
@

ALTER TABLE GOSALESCT.CUST_CRDTCRD ADD CONSTRAINT CUST_CRDTCRD_CUST_FK FOREIGN KEY (CUST_CODE)
	REFERENCES GOSALESCT.CUST (CUST_CODE)
	ON DELETE RESTRICT
@

ALTER TABLE GOSALESCT.CUST_INV ADD CONSTRAINT CUST_INV_CUST_ORD_FK FOREIGN KEY (ORD_NBR)
	REFERENCES GOSALESCT.CUST_ORD (ORD_NBR)
@

ALTER TABLE GOSALESCT.CUST_ORD_DETL ADD CONSTRAINT CUST_ORD_DETL_PRODUCT_FK FOREIGN KEY (PROD_NBR)
	REFERENCES GOSALES.PRODUCT (PRODUCT_NUMBER)
	ON DELETE CASCADE
@
	
ALTER TABLE GOSALESCT.CUST_ORD_DETL ADD CONSTRAINT CUST_ORD_DETL_CUST_ORD_FK FOREIGN KEY (ORD_NBR)
	REFERENCES GOSALESCT.CUST_ORD (ORD_NBR)
@

ALTER TABLE GOSALESCT.CUST_ORD ADD CONSTRAINT ORDER_METHOD_CUST_ORD_FK FOREIGN KEY (ORD_METH_CODE)
    REFERENCES GOSALES.ORDER_METHOD(ORDER_METHOD_CODE)
    ON DELETE RESTRICT
@

------------------------------------------------
-- CREATE VIEW GOSALESCT.CUST_ORD_STATUS
-- This view shows customer id, customer last name, order nubmer, order data, total order amount and order status
------------------------------------------------

CREATE VIEW GOSALESCT.CUST_ORD_STATUS (CUSTOMER_ID, CUST_LST_NAME, ORDER_NUBMER, ORDER_DATE, VALUE_OF_ORDER, ORDER_STATUS) AS 
       SELECT C.CUST_CODE, CAST(C.CUST_LAST_NAME AS VARCHAR(15)), 
              O.ORD_NBR, O.ORD_DATE, O.ORD_TOT_COST, CAST(O.ORD_STAT AS VARCHAR(15))
       FROM GOSALESCT.CUST C, GOSALESCT.CUST_ORD O
@
	   
------------------------------------------------
-- CREATE VIEW GOSALESCT.CUST_TAX_STAT
-- Used for customer tax statistics 
------------------------------------------------
CREATE VIEW GOSALESCT.CUST_TAX_STAT (CUST_ID, CUST_CITY,  CUST_ZIPCODE, CUST_STATE, CUST_TAX_RATE) AS
	   SELECT C.CUST_CODE, C.CUST_CITY, C.CUST_POST_ZONE, C.CUST_PROV_STATE, ST.CUST_TAX_RATE
	   FROM GOSALESCT.CUST C, GOSALESCT.CUST_STATE_TAX ST
@

CREATE  	VIEW GOSALES.BASE_PRODUCT_SUM AS
SELECT  	BASE_PRODUCT_NUMBER
 	  	AS BASE_PROD, 
	  	SUM(PRODUCTION_COST) AS SUM_PROD_COST
FROM 	  	GOSALES.PRODUCT
GROUP BY 	BASE_PRODUCT_NUMBER
@

COMMENT ON 	TABLE GOSALES.BASE_PRODUCT_SUM IS 'View Example of Product Table'
@

------------------------------------------------
-- CREATE PROCEDURE GOSALESCT.NUM_OF_ORDERS
-- call gosalesct.num_of_orders (105,?)
------------------------------------------------
CREATE PROCEDURE GOSALESCT.NUM_OF_ORDERS(IN CUSTOMERID INTEGER,
                                         OUT NUM_OF_ORD INTEGER)
SPECIFIC GOSALESCT.NUM_OF_ORDERS
BEGIN
   SELECT COUNT(*) INTO NUM_OF_ORD 
      FROM GOSALESCT.CUST_ORD
      WHERE CUST_CODE = CUSTOMERID;
END
@

------------------------------------------------
-- GOSALESCT.GET_CUSTOMER_NAME
-- call GOSALESCT.GET_CUSTOMER_NAME (105,?,?,?)
------------------------------------------------
CREATE PROCEDURE GOSALESCT.GET_CUSTOMER_NAME(IN CUSTOMERID INTEGER,
                                             OUT FIRST_NAME VARCHAR(128),
                                             OUT LAST_NAME VARCHAR(128),
                                             OUT PHONE_NUMBER VARCHAR(128))
SPECIFIC GOSALESCT.GET_CUSTOMER_NAME
BEGIN
   SELECT CUST_FRST_NAME 
     INTO FIRST_NAME
     FROM GOSALESCT.CUST
    WHERE CUST_CODE = CUSTOMERID;
    
   SELECT CUST_LAST_NAME
     INTO LAST_NAME
     FROM GOSALESCT.CUST
    WHERE CUST_CODE = CUSTOMERID;
    
   SELECT CUST_PHN_NBR
     INTO PHONE_NUMBER
     FROM GOSALESCT.CUST
    WHERE CUST_CODE = CUSTOMERID;    
END
@

CREATE PROCEDURE GOSALES.PRODUCT_CATALOG (IN PRODUCT_TYPE VARCHAR(50))
	DYNAMIC RESULT SETS 1
------------------------------------------------------------------------
-- SQL Stored Procedure 
------------------------------------------------------------------------
SPECIFIC GOSALES.PRODUCT_CATALOG
P1: BEGIN
	-- Declare cursor
	DECLARE CURSOR1 CURSOR WITH RETURN FOR
		SELECT P.PRODUCT_NUMBER, 
		       Q.PRODUCT_NAME, 
		       Q.PRODUCT_DESCRIPTION,  
		       P.PRODUCTION_COST, 
		       P.PRODUCT_IMAGE  
	      FROM GOSALES.PRODUCT AS P, 
	           GOSALES.PRODUCT_NAME_LOOKUP AS Q, 
	           GOSALES.PRODUCT_TYPE AS R  
	     WHERE P.PRODUCT_NUMBER = Q.PRODUCT_NUMBER 
	       AND Q.PRODUCT_LANGUAGE = 'EN'    
	       AND R.PRODUCT_TYPE_CODE = P.PRODUCT_TYPE_CODE 
	       AND R.PRODUCT_TYPE_EN = PRODUCT_TYPE;

	-- Cursor left open for client application
	OPEN CURSOR1;
END P1

@

CREATE	SEQUENCE GOSALES.PROD_SEQ 
     		START WITH 1
     		INCREMENT BY 1
     		MAXVALUE 100000
     		NO CYCLE
     		CACHE 20 
@



CREATE 	SEQUENCE GOSALES.ORG_SEQ AS BIGINT
     		START WITH 100
     		INCREMENT BY 5
     		NO MAXVALUE
     		CYCLE
     		CACHE 5 
@

COMMIT
@

CONNECT RESET
@

