::  DB2 9.7 Admin for Experienced DBAs
::  Copyright(r) IBM Corporation
::
::  Vikram Khatri (vikram.khatri@us.ibm.com)
::  Burt Vialpando (burt.vialpando@us.ibm.com)
::

REM ------------------------------------------------------------------- 
REM Show DB2 Database Admin Views to query database specific information
REM ------------------------------------------------------------------- 

TITLE Database03.CMD - Show Admin Views

SET OUTFILE=%~n0_OUTPUT.TXT

@echo off
cls

ECHO ---------------------------------------------------------------------
ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% %TIME%
ECHO ---------------------------------------------------------------------


ECHO.
ECHO ---------------------------------------------------------------------
ECHO Running administration view queries now...
ECHO ---------------------------------------------------------------------
ECHO.


set db2instance=db2

db2 connect to sample > NUL
ECHO --------------------------------------------------------------------- 	>  %OUTFILE%
ECHO Show Physical space used by tables 					>> %OUTFILE%
ECHO --------------------------------------------------------------------- 	>> %OUTFILE%

db2 -v SELECT SUBSTR(TABSCHEMA,1,12) 			TABSCHEMA,^
        	 SUBSTR(TABNAME,1,25) 	 		TABNAME,^
        	 INTEGER(SUM(DATA_OBJECT_P_SIZE))  	DATA_OB_P_SIZE,^
        	 INTEGER(SUM(INDEX_OBJECT_P_SIZE))	INDEX_OB_P_SIZE,^
        	 INTEGER(SUM(LONG_OBJECT_P_SIZE))	LONG_OB_P_SIZE,^
        	 INTEGER(SUM(LOB_OBJECT_P_SIZE))	LOB_OB_P_SIZE,^
        	 INTEGER(SUM(XML_OBJECT_P_SIZE))	XML_OB_P_SIZE^
      FROM 	 SYSIBMADM.ADMINTABINFO^
      WHERE 	 TABSCHEMA NOT LIKE 'SYS%%'^
      GROUP BY TABSCHEMA, TABNAME >> %OUTFILE%


ECHO. 										>> %OUTFILE%
ECHO ---------------------------------------------------------------------	>> %OUTFILE%
ECHO Show Database size and maximum capacity 					>> %OUTFILE%
ECHO ---------------------------------------------------------------------	>> %OUTFILE%

db2 -v 	CALL GET_DBSIZE_INFO(?, ?, ?, 0) 					>> %OUTFILE%


ECHO. 										>> %OUTFILE%
ECHO ---------------------------------------------------------------------- 	>> %OUTFILE%
ECHO Show Connected applications to Database 					>> %OUTFILE%
ECHO ---------------------------------------------------------------------- 	>> %OUTFILE%

db2 -v 	SELECT 	AGENT_ID, SUBSTR(APPL_NAME,1,10) AS APPL_NAME, ^
		SUBSTR(AUTHID,1,20) AS AUTHID,^
   		APPL_STATUS ^
	FROM 	SYSIBMADM.APPLICATIONS ^
	WHERE 	DB_NAME LIKE 'SAMPLE%%' 					>> %OUTFILE%


ECHO. 										>> %OUTFILE%
ECHO ---------------------------------------------------------------------	>> %OUTFILE%
ECHO Show top 5 most frequently run Dynamic SQL 				>> %OUTFILE%
ECHO --------------------------------------------------------------------- 	>> %OUTFILE%

db2 -v 	SELECT 	NUM_EXECUTIONS, AVERAGE_EXECUTION_TIME_S,^
    		SUBSTR(STMT_TEXT,1,60) AS STMT_TEXT^
    	FROM 	SYSIBMADM.TOP_DYNAMIC_SQL^
    	ORDER 	BY NUM_EXECUTIONS DESC ^
	FETCH 	FIRST 5 ROWS ONLY 						>> %OUTFILE%


ECHO. 										>> %OUTFILE%
ECHO ---------------------------------------------------------------------	>> %OUTFILE%
ECHO List Tablespaces 								>> %OUTFILE%
ECHO --------------------------------------------------------------------- 	>> %OUTFILE%

db2 -v 	SELECT 	TBSP_ID, SUBSTR(TBSP_NAME,1,20) as TBSP_NAME, TBSP_TYPE,^
   		TBSP_CONTENT_TYPE, SUBSTR(TBSP_STATE,1,20) TBST_STATE^
   	FROM 	SYSIBMADM.TBSP_UTILIZATION 					>> %OUTFILE%


ECHO. 										>> %OUTFILE%
ECHO ---------------------------------------------------------------------	>> %OUTFILE%
ECHO Bufferpool hit ratio 							>> %OUTFILE%
ECHO ---------------------------------------------------------------------	>> %OUTFILE%

db2 -v 	SELECT 	SUBSTR(DB_NAME,1,8) AS DB_NAME, SUBSTR(BP_NAME,1,40) AS BP_NAME,^
   		TOTAL_HIT_RATIO_PERCENT^
   	FROM 	SYSIBMADM.BP_HITRATIO 						>> %OUTFILE%


ECHO. 										>> %OUTFILE%
ECHO --------------------------------------------------------------------- 	>> %OUTFILE%
ECHO List the log utilization for the currently connected database 		>> %OUTFILE%
ECHO --------------------------------------------------------------------- 	>> %OUTFILE%

db2 -v 	SELECT 	SUBSTR(DB_NAME,1,10) DB_NAME, LOG_UTILIZATION_PERCENT^
    		TOTAL_LOG_USED_KB, TOTAL_LOG_AVAILABLE_KB^
    	FROM 	SYSIBMADM.LOG_UTILIZATION 					>> %OUTFILE%


ECHO. 										>> %OUTFILE%
ECHO --------------------------------------------------------------------- 	>> %OUTFILE%
ECHO Get all critical log messages logged in the last 24 hours 			>> %OUTFILE%
ECHO --------------------------------------------------------------------- 	>> %OUTFILE%

db2 -v 	SELECT 	TIMESTAMP, SUBSTR(DBNAME,1,10) DBNAME, SUBSTR(MSG,1,80) MSG^
    	FROM 	SYSIBMADM.PDLOGMSGS_LAST24HOURS^
   	WHERE 	MSGSEVERITY = 'C' ^
	ORDER 	BY TIMESTAMP DESC 						>> %OUTFILE%


ECHO. 										>> %OUTFILE%
ECHO --------------------------------------------------------------------- 	>> %OUTFILE%
ECHO Show Database paths 							>> %OUTFILE%
ECHO --------------------------------------------------------------------- 	>> %OUTFILE%

db2 -v 	SELECT 	SUBSTR(TYPE,1,20) TYPE, SUBSTR(PATH,1,50) PATH ^
	FROM 	SYSIBMADM.DBPATHS 						>> %OUTFILE%


db2 connect reset 								>> NUL

ECHO.
ECHO ---------------------------------------------------------------------
ECHO Note: The heart of this script are the various SQL using admin views.
ECHO       Please review %OUTFILE% for output for details 
ECHO       on these views.
ECHO ---------------------------------------------------------------------
ECHO.