-- --------------------------------------------------------------------- 
-- Create a VIEW before the function it references is built
-- ---------------------------------------------------------------------

CREATE 	OR REPLACE VIEW SCHEMA_CHANGE_SUPERVISORS_VW AS 
	SELECT  SCHEMA_CHANGE_FULL_NAME(SCHEMA_CHANGE_TB_ID) AS FULL_NAME, 
		SALARY
	FROM 	SCHEMA_CHANGE_TB
	WHERE 	JOB_CODE = 'SUPR';

-- --------------------------------------------------------------------- 
-- Create a FUNCTION before the table it references is built
-- ---------------------------------------------------------------------

CREATE 	OR REPLACE FUNCTION SCHEMA_CHANGE_FULL_NAME (p_ID INTEGER)
	SPECIFIC SCHEMA_CHANGE_FULL_NAME
	RETURNS VARCHAR(42)
	RETURN 	SELECT RTRIM(LAST_NAME) || ', ' || RTRIM(FIRST_NAME) AS FULL_NAME
		FROM   SCHEMA_CHANGE_TB
		WHERE  SCHEMA_CHANGE_TB_ID = p_ID;

-- --------------------------------------------------------------------- 
-- Create the TABLE: SCHEMA_CHANGE_TB 
-- --------------------------------------------------------------------- 
DROP	TABLE SCHEMA_CHANGE_TB;
CREATE 	TABLE SCHEMA_CHANGE_TB
      ( SCHEMA_CHANGE_TB_ID  INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY (START WITH 100000, INCREMENT BY 5),
   	SSN            CHAR(11)      NOT NULL,
   	FIRST_NAME     VARCHAR(20)   NOT NULL,
   	LAST_NAME      VARCHAR(20)   NOT NULL,
   	JOB_CODE       CHAR(4) 	     NOT NULL,
   	DEPT           SMALLINT      NOT NULL,
   	SALARY         DECIMAL(12,2) NOT NULL,
   	DOB            DATE          NOT NULL WITH DEFAULT,
   	CONSTRAINT     PK_SCHEMA_CHANGE_TB PRIMARY KEY (SCHEMA_CHANGE_TB_ID)
      ) ;

COMMIT;

-- --------------------------------------------------------------------- 
-- insert generated records into TABLE: SCHEMA_CHANGE_TB
-- --------------------------------------------------------------------- 
INSERT 	INTO SCHEMA_CHANGE_TB 
	(SSN,FIRST_NAME,LAST_NAME,JOB_CODE,DEPT,SALARY,DOB)
	WITH TEMP1 (s1,r1,r2,r3,r4) AS
	(VALUES (0
	,RAND(2)
	,RAND()+(RAND()/1E5)
	,RAND()* RAND()
	,RAND()* RAND()* RAND())
	  UNION ALL
	SELECT s1 + 1
	,RAND()
	,RAND()+(RAND()/1E5)
	,RAND()* RAND()
	,RAND()* RAND()* RAND()
	FROM TEMP1
	WHERE s1 < 1999
	)
	SELECT  SUBSTR(DIGITS(INT(r2*988+10)),8) ||'-'||
       		SUBSTR(DIGITS(INT(r1*88+10)),9) || '-' ||
       		TRANSLATE(SUBSTR(DIGITS(s1),7),'9873450126','0123456789'),
       		CHR(INT(r1*26+65))|| CHR(INT(r2*26+97))|| CHR(INT(r3*26+97))||CHR(INT(r4*26+97))|| CHR(INT(r3*10+97))|| CHR(INT(r3*11+97)),
       		CHR(INT(r2*26+65))||TRANSLATE(CHAR(INT(r2*1E7)),'aaeeiibmty','0123456789'),       
       		CASE
         		WHEN INT(r4*9) > 7 THEN 'MGR'
         		WHEN INT(r4*9) > 5 THEN 'SUPR'
         		WHEN INT(r4*9) > 3 THEN 'PGMR'
         		WHEN INT(R4*9) > 1 THEN 'SEC'
         		ELSE 'WKR'
       		END,
       		INT(r3*98+1),
       		DECIMAL(r4*99999,7,2),
       		DATE('1930-01-01') + INT(50-(r4*50)) YEARS + INT(r4*11) MONTHS + INT(r4*27) DAYS
	FROM TEMP1;
COMMIT;

-- --------------------------------------------------------------------- 
-- Check to see that everything works
-- --------------------------------------------------------------------- 

SELECT * FROM SCHEMA_CHANGE_SUPERVISORS_VW 
	 FETCH FIRST 20 ROWS ONLY;

