-- 
-- Oracle Schema:  CREATE TRIGGERS
--

CREATE OR REPLACE TRIGGER CascadeRSInserts
  /* Keep the registered_students, students, and classes
     tables in synch. */
  AFTER INSERT ON registered_students
  FOR EACH ROW

DECLARE
  v_Credits classes.num_credits%TYPE;
BEGIN
  -- Determine the number of credits for this class.
  SELECT num_credits
    INTO v_Credits
    FROM classes
    WHERE department = :new.department
    AND course = :new.course;

  -- Modify the current credits for this student.
  UPDATE students
    SET current_credits = current_credits + v_Credits
    WHERE ID = :new.student_id;

  -- Add one to the number of students in the class.
  UPDATE classes
    SET current_students = current_students + 1
    WHERE department = :new.department
    AND course = :new.course;
END CascadeRSInserts;
/



CREATE OR REPLACE TRIGGER classes_ARow
  AFTER UPDATE ON classes
  FOR EACH ROW

BEGIN
  INSERT INTO temp_table (num_col, char_col)
    VALUES (trigger_seq.NEXTVAL, 'After Row trigger');
END classes_ARow;

/



CREATE OR REPLACE TRIGGER classes_AStatement
  AFTER UPDATE ON classes
  FOR EACH ROW

BEGIN
  INSERT INTO temp_table (num_col, char_col)
    VALUES (trigger_seq.NEXTVAL, 'After Statement trigger');
END classes_AStatement;

/


CREATE OR REPLACE TRIGGER classes_BRow
  AFTER UPDATE ON classes
  FOR EACH ROW

BEGIN
  INSERT INTO temp_table (num_col, char_col)
    VALUES (trigger_seq.NEXTVAL, 'Before Row trigger');
END classes_BRow;

/



CREATE OR REPLACE TRIGGER LimitMajors
  -- Limits the number of students in each major to 5.
  -- If this limit is exceeded, an error is raised through
  -- raise_application_error.
  AFTER INSERT ON students
  FOR EACH ROW

DECLARE
  v_MaxStudents CONSTANT NUMBER := 5;
  v_CurrentStudents NUMBER;

BEGIN 
  -- Determine the current number of students in this
  -- major.
  SELECT COUNT(*)
    INTO v_CurrentStudents
    FROM students
    WHERE major = :new.major;

  -- If there isn't room, raise an error.
 IF v_CurrentStudents + 1 > v_MaxStudents THEN
   RAISE_APPLICATION_ERROR(-20000,
     'Too many students in major ' || :new.major);
 END IF;
END LimitMajors;
/



CREATE OR REPLACE TRIGGER major_stats
  AFTER INSERT ON major_stats
  FOR EACH ROW

BEGIN
  INSERT INTO temp_table (char_col)
    VALUES ('Trigger fired!');
END major_stats;

/



CREATE OR REPLACE TRIGGER room_summary_delete
  INSTEAD OF DELETE ON room_summary
  FOR EACH ROW

BEGIN
  -- Delete all of the rows in rooms which match this single row
  -- in room_summary
  DELETE FROM rooms
    WHERE building = :old.building;
END room_summary_delete;
/

;