::  DB2 9.7 Admin for Experienced DBAs
::  Copyright(r) IBM Corporation
::
::  Vikram Khatri (vikram.khatri@us.ibm.com)
::

REM ------------------------------------------------------------------- 
REM Security Lab 06 - DB2 Label Based Access Control quick look                                
REM ------------------------------------------------------------------- 

TITLE Security09.CMD - DB2 Label Based Access Control quick look

SET OUTFILE=%~n0_OUTPUT.TXT

@echo off
cls
ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% 
ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% > %OUTFILE%


ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO Creating a security label to protect data       			   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%


db2 CONNECT TO SAMPLE USER SECPOT USING SECPOT12345 > NUL

REM
REM Resetting lab 
REM

db2 drop table account.sales > NUL

db2 revoke security label SALES_REGION_POLICY.SALES_ORG  from USER CEO     > NUL
db2 revoke security label SALES_REGION_POLICY.EAST_COAST from USER EAST    > NUL
db2 revoke security label SALES_REGION_POLICY.WEST_COAST from USER WEST    > NUL
db2 revoke security label SALES_REGION_POLICY.CENTRAL    from USER CENTRAL > NUL

db2 drop security label SALES_REGION_POLICY.SALES_ORG     > NUL
db2 drop security label SALES_REGION_POLICY.CENTRAL       > NUL
db2 drop security label SALES_REGION_POLICY.CENTRAL_NORTH > NUL
db2 drop security label SALES_REGION_POLICY.CENTRAL_SOUTH > NUL
db2 drop security label SALES_REGION_POLICY.EAST_COAST    > NUL
db2 drop security label SALES_REGION_POLICY.WEST_COAST    > NUL

db2 drop security policy SALES_REGION_POLICY > NUL
db2 drop SECURITY LABEL COMPONENT SLC_REGION > NUL


db2 -vz %OUTFILE% CREATE SECURITY LABEL COMPONENT SLC_REGION ^
        TREE ('SALES_ORGANIZATION' ROOT,^
              'CENTRAL' UNDER 'SALES_ORGANIZATION',^
              'CENTRAL_NORTH' UNDER 'CENTRAL',^
              'CENTRAL_SOUTH' UNDER 'CENTRAL',^
              'WEST_COAST' UNDER 'SALES_ORGANIZATION',^
              'EAST_COAST' UNDER 'SALES_ORGANIZATION' ^
        )


ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO Creating a security policy	 		      			   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%

db2 -vz %OUTFILE% CREATE SECURITY POLICY SALES_REGION_POLICY ^
             COMPONENTS SLC_REGION ^
             WITH DB2LBACRULES ^
             RESTRICT NOT AUTHORIZED WRITE SECURITY LABEL


ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO Creating a protected sales table 		      			   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%

db2 -vz %OUTFILE% CREATE TABLE ACCOUNT.SALES (SALES_DATE DATE, ^
             SALES_PERSON VARCHAR (15),^
             REGION VARCHAR (15),^
             SALES INTEGER,^
             MARGIN INTEGER,^
             REGION_TAG DB2SECURITYLABEL)^
             SECURITY POLICY SALES_REGION_POLICY


ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO Defining security labels for West, East and Central		   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%

db2 -vz %OUTFILE%  CREATE SECURITY LABEL SALES_REGION_POLICY.CENTRAL_SOUTH  COMPONENT SLC_REGION 'CENTRAL_SOUTH'        
db2 -vz %OUTFILE%  CREATE SECURITY LABEL SALES_REGION_POLICY.CENTRAL_NORTH  COMPONENT SLC_REGION 'CENTRAL_NORTH'             
db2 -vz %OUTFILE%  CREATE SECURITY LABEL SALES_REGION_POLICY.EAST_COAST     COMPONENT SLC_REGION 'EAST_COAST'
db2 -vz %OUTFILE%  CREATE SECURITY LABEL SALES_REGION_POLICY.WEST_COAST     COMPONENT SLC_REGION 'WEST_COAST'
db2 -vz %OUTFILE%  CREATE SECURITY LABEL SALES_REGION_POLICY.CENTRAL        COMPONENT SLC_REGION 'CENTRAL'
db2 -vz %OUTFILE%  CREATE SECURITY LABEL SALES_REGION_POLICY.SALES_ORG      COMPONENT SLC_REGION 'SALES_ORGANIZATION'


ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO Grant security lables to users					   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%

db2 -vz %OUTFILE% GRANT SECURITY LABEL SALES_REGION_POLICY.SALES_ORG      TO USER CEO     FOR READ ACCESS
db2 -vz %OUTFILE% GRANT SECURITY LABEL SALES_REGION_POLICY.EAST_COAST     TO USER EAST    FOR ALL  ACCESS           
db2 -vz %OUTFILE% GRANT SECURITY LABEL SALES_REGION_POLICY.WEST_COAST     TO USER WEST    FOR ALL  ACCESS
db2 -vz %OUTFILE% GRANT SECURITY LABEL SALES_REGION_POLICY.CENTRAL        TO USER CENTRAL FOR ALL  ACCESS


ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO Create the users CEO, EAST, WEST, CENTRAL				   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%

CALL :CreateUser CEO
CALL :CreateUser EAST
CALL :CreateUser WEST
CALL :CreateUser CENTRAL


ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO Grant basic access to all users					   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%

db2 -vz %OUTFILE% connect to sample
db2 -vz %OUTFILE% grant insert,update,select,delete on ACCOUNT.SALES to CEO,EAST,WEST,CENTRAL



ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO User EAST INSERTS data for East region				   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%

db2 -vz %OUTFILE% CONNECT TO SAMPLE USER EAST USING EAST12345

db2 -vz %OUTFILE% INSERT into ACCOUNT.SALES VALUES ('2005-02-28','Barry','East-Coast',344,40, ^
                  SECLABEL_BY_NAME('SALES_REGION_POLICY', 'EAST_COAST'))
db2 -vz %OUTFILE% INSERT into ACCOUNT.SALES (SALES_DATE, SALES_PERSON, REGION, SALES, MARGIN) ^
                  VALUES ('2005-02-12','Vikram','East-Coast',450,40)


ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO User WEST INSERTS data for West region				   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%

db2 -vz %OUTFILE% CONNECT TO SAMPLE USER WEST USING WEST12345

db2 -vz %OUTFILE% INSERT into ACCOUNT.SALES (SALES_DATE, SALES_PERSON, REGION, SALES, MARGIN) ^
                  VALUES ('2009-03-12','Burt','West-Coast',850,80)


ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO User CENTRAL INSERTS data for Central-North region			   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%

db2 -vz %OUTFILE% CONNECT TO SAMPLE USER CENTRAL USING CENTRAL12345

db2 -vz %OUTFILE% INSERT into ACCOUNT.SALES (SALES_DATE, SALES_PERSON, REGION, SALES, MARGIN) ^
                  VALUES ('2009-06-28','Nick','Central-North',1850,10)


ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO User CEO does a SELECT on the SALES table, sees all 4 records	   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%

db2 -vz %OUTFILE% CONNECT TO SAMPLE USER CEO USING CEO12345

db2 -vz %OUTFILE% SELECT SALES_DATE, SALES_PERSON, REGION, SALES FROM ACCOUNT.SALES


ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO User EAST does a SELECT on the SALES table, sees 2 record		   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%

db2 -vz %OUTFILE% CONNECT TO SAMPLE USER EAST USING EAST12345

db2 -vz %OUTFILE% SELECT SALES_DATE, SALES_PERSON, REGION, SALES FROM ACCOUNT.SALES


ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO User WEST does a SELECT on the SALES table, sees 1 record		   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%

db2 -vz %OUTFILE% CONNECT TO SAMPLE USER WEST USING WEST12345

db2 -vz %OUTFILE% SELECT SALES_DATE, SALES_PERSON, REGION, SALES FROM ACCOUNT.SALES


ECHO. 									   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO User CENTRAL does a SELECT on the SALES table, sees 1 record	   >> %OUTFILE%
ECHO --------------------------------------------------------------------- >> %OUTFILE%
ECHO. 									   >> %OUTFILE%

db2 -vz %OUTFILE% CONNECT TO SAMPLE USER CENTRAL USING CENTRAL12345

db2 -vz %OUTFILE% SELECT SALES_DATE, SALES_PERSON, REGION, SALES FROM ACCOUNT.SALES

ECHO.
ECHO ---------------------------------------------------------------------
ECHO Review the FILE '%OUTFILE%' for details on 
ECHO this LBAC exercise
ECHO ---------------------------------------------------------------------
ECHO.

GOTO :EOF

:CreateUser
setlocal
REM Create user, if it does not exists
net user %1  2>NUL > NUL
IF %ERRORLEVEL% EQU 2 (
   ECHO CREATING USER %1
   NET USER /ADD %1 %112345 2>NUL > NUL
) ELSE (
   ECHO User %1 already exists
)
ECHO.
endlocal

