-- ------------------------------------------------------------------- 
-- Explain Lab 07 - Union All View Setup #1
-- ------------------------------------------------------------------- 
-- This script creates the buffer pools, table spaces and tables 
-- needed to show a union all view.  Then it creates the union all
-- View itself.  Tables are named Q1_2009 through Q4_2009.  
-- View is YEAR_2009.
-- ------------------------------------------------------------------- 

--------------------------------
-- CREATE BUFFERPOOLS 	     --
--------------------------------

ECHO -;
ECHO -------------------------;
ECHO Creating Buffer Pools...;
ECHO -------------------------;


CREATE BUFFERPOOL BP4_DATA
IMMEDIATE  
SIZE 2000
PAGESIZE 4 K;

CREATE BUFFERPOOL BP4_INDEX
IMMEDIATE  
SIZE 2000 
PAGESIZE 4 K;

--------------------------------
-- CREATE DMS TABLESPACES     --
--------------------------------
ECHO -;
ECHO -------------------------;
ECHO Creating Tablespaces...;
ECHO -------------------------;

DROP TABLE Q1_2009;
DROP TABLE Q2_2009;
DROP TABLE Q3_2009;
DROP TABLE Q4_2009;

DROP TABLESPACE Q1_2009_DATA;
DROP TABLESPACE Q2_2009_DATA;
DROP TABLESPACE Q3_2009_DATA;
DROP TABLESPACE Q4_2009_DATA;
DROP TABLESPACE Q1_2009_INDEX;
DROP TABLESPACE Q2_2009_INDEX;
DROP TABLESPACE Q3_2009_INDEX;
DROP TABLESPACE Q4_2009_INDEX;

CREATE TABLESPACE Q1_2009_DATA 
PAGESIZE 	4 K  
MANAGED 	BY DATABASE  
USING 		( FILE 'C:\DB2\Q1_2009_DATA_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 	16 
OVERHEAD 	10.5 
PREFETCHSIZE 	16 
TRANSFERRATE 	0.14 
BUFFERPOOL  	BP4_DATA 
DROPPED TABLE 	RECOVERY ON;

CREATE TABLESPACE Q1_2009_INDEX 
PAGESIZE 	4 K  
MANAGED 	BY DATABASE  
USING 		( FILE 'C:\DB2\Q1_2009_INDEX_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 	16 
OVERHEAD 	10.5 
PREFETCHSIZE 	16 
TRANSFERRATE 	0.14 
BUFFERPOOL  	BP4_INDEX
DROPPED TABLE 	RECOVERY ON;

CREATE TABLESPACE Q2_2009_DATA 
PAGESIZE 	4 K  
MANAGED 	BY DATABASE  
USING 		( FILE 'C:\DB2\Q2_2009_DATA_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 	16 
OVERHEAD 	10.5 
PREFETCHSIZE 	16 
TRANSFERRATE 	0.14 
BUFFERPOOL  	BP4_DATA 
DROPPED TABLE RECOVERY ON;

CREATE TABLESPACE Q2_2009_INDEX 
PAGESIZE 	4 K  
MANAGED 	BY DATABASE  
USING 		( FILE 'C:\DB2\Q2_2009_INDEX_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 	16 
OVERHEAD 	10.5 
PREFETCHSIZE 	16 
TRANSFERRATE 	0.14 
BUFFERPOOL  	BP4_INDEX
DROPPED TABLE 	RECOVERY ON;

CREATE TABLESPACE Q3_2009_DATA 
PAGESIZE 	4 K  
MANAGED 	BY DATABASE  
USING 		( FILE 'C:\DB2\Q3_2009_DATA_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 	16 
OVERHEAD 	10.5 
PREFETCHSIZE 	16 
TRANSFERRATE 	0.14 
BUFFERPOOL  	BP4_DATA 
DROPPED TABLE 	RECOVERY ON;

CREATE TABLESPACE Q3_2009_INDEX 
PAGESIZE 	4 K  
MANAGED 	BY DATABASE  
USING 		( FILE 'C:\DB2\Q3_2009_INDEX_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 	16 
OVERHEAD 	10.5 
PREFETCHSIZE 	16 
TRANSFERRATE 	0.14 
BUFFERPOOL  	BP4_INDEX
DROPPED TABLE 	RECOVERY ON;

CREATE TABLESPACE Q4_2009_DATA 
PAGESIZE 	4 K  
MANAGED 	BY DATABASE  
USING 		( FILE 'C:\DB2\Q4_2009_DATA_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 	16 
OVERHEAD 	10.5 
PREFETCHSIZE 	16 
TRANSFERRATE 	0.14 
BUFFERPOOL  	BP4_DATA 
DROPPED TABLE 	RECOVERY ON;

CREATE TABLESPACE Q4_2009_INDEX 
PAGESIZE 	4 K  
MANAGED 	BY DATABASE  
USING 		( FILE 'C:\DB2\Q4_2009_INDEX_CONTAINER1.DBF' 640 ) 
EXTENTSIZE 	16 
OVERHEAD 	10.5 
PREFETCHSIZE 	16 
TRANSFERRATE 	0.14 
BUFFERPOOL  	BP4_INDEX
DROPPED TABLE 	RECOVERY ON;

--------------------------------
-- CREATE 4 QUARTERLY TABLES  --
--------------------------------

ECHO -;
ECHO -------------------------;
ECHO Creating Tables...;
ECHO -------------------------;

create table Q1_2009
  (
  tx_number  int not null,
  tx_item    char(10) not null,
  tx_quantity int not null,
  tx_date    date not null,
     check (tx_date between '2009-01-01' and '2009-03-31')
  )
  in Q1_2009_DATA index in Q1_2009_INDEX;

create table Q2_2009
  (
  tx_number  int not null,
  tx_item    char(10) not null,
  tx_quantity int not null,
  tx_date    date not null,
     check (tx_date between '2009-04-01' and '2009-06-30')
  )
in Q2_2009_DATA index in Q2_2009_INDEX;


create table Q3_2009
  (
  tx_number  int not null,
  tx_item    char(10) not null,
  tx_quantity int not null,
  tx_date    date not null,
     check (tx_date between '2009-07-01' and '2009-09-30')
  )
in Q3_2009_DATA index in Q3_2009_INDEX;


create table Q4_2009
  (
  tx_number  int not null,
  tx_item    char(10) not null,
  tx_quantity int not null,
  tx_date    date not null,
     check (tx_date between '2009-10-01' and '2009-12-31')
  )
  in Q4_2009_DATA index in Q4_2009_INDEX;


--------------------------------
-- CREATE UNION ALL VIEW      --
--------------------------------

ECHO -;
ECHO -------------------------;
ECHO Creating Union All View...;
ECHO -------------------------;

drop   view Year_2009;
create view Year_2009 as
  (
  select * from Q1_2009
  union all
  select * from Q2_2009
  union all 
  select * from Q3_2009
  union all
  select * from Q4_2009
  ) 
WITH ROW MOVEMENT;

COMMIT WORK;
