-- ------------------------------------------------------------------- 
-- MDC Lab 10 - Multidimensional Table Setup
-- ------------------------------------------------------------------- 
-- This script creates the table spaces and the tables to show how
-- multidimensional clusters work.  Two tables, CARS and CARS_MDC
-- are created in their own table spaces.
--
-- Table CARS_TIMING_CHECK is created which is used to save timing
-- data for our test with both tables.
--


CONNECT TO GSDB;
ECHO -;
ECHO -------------------------;
ECHO Connecting to GSDB...;
ECHO -------------------------;


--------------------------------
-- CREATE TABLESPACES         --
--------------------------------
ECHO -;
ECHO -------------------------;
ECHO Creating Tablespaces...;
ECHO -------------------------;

DROP TABLE CARS;
DROP TABLE CARS_MDC;

DROP TABLESPACE CARS_DATA;
DROP TABLESPACE CARS_INDEX;
DROP TABLESPACE CARS_MDC_DATA;
DROP TABLESPACE CARS_MDC_INDEX;

DROP BUFFERPOOL CARS_MDC_BP_DATA;
DROP BUFFERPOOL CARS_MDC_BP_INDEX;
DROP BUFFERPOOL CARS_BP_DATA;
DROP BUFFERPOOL CARS_BP_INDEX;

CREATE BUFFERPOOL CARS_MDC_BP_DATA 
IMMEDIATE  
SIZE 1000 
PAGESIZE 4 K;

CREATE BUFFERPOOL CARS_MDC_BP_INDEX 
IMMEDIATE  
SIZE 100 
PAGESIZE 4 K;

CREATE BUFFERPOOL CARS_BP_DATA 
IMMEDIATE  
SIZE 1000 
PAGESIZE 4 K;

CREATE BUFFERPOOL CARS_BP_INDEX
IMMEDIATE  
SIZE 100 
PAGESIZE 4 K;

CREATE 	LARGE TABLESPACE CARS_DATA 
PAGESIZE 4 K  
MANAGED BY DATABASE  
USING ( FILE 'C:\DB2\CARS_DATA_CONTAINER1.DBF' 15M ) 
EXTENTSIZE 2 
OVERHEAD 10.5 
PREFETCHSIZE 8 
TRANSFERRATE 0.14 
BUFFERPOOL CARS_BP_DATA
DROPPED TABLE RECOVERY OFF;

CREATE LARGE TABLESPACE CARS_INDEX 
PAGESIZE 4 K  
MANAGED BY DATABASE  
USING ( FILE 'C:\DB2\CARS_INDEX_CONTAINER1.DBF' 15M ) 
EXTENTSIZE 2 
OVERHEAD 10.5 
PREFETCHSIZE 8 
TRANSFERRATE 0.14 
BUFFERPOOL CARS_BP_INDEX
DROPPED TABLE RECOVERY OFF;

CREATE LARGE TABLESPACE CARS_MDC_DATA 
PAGESIZE 4 K  
MANAGED BY DATABASE  
USING ( FILE 'C:\DB2\CARS_MCD_DATA_CONTAINER1.DBF' 15M ) 
EXTENTSIZE 2 
OVERHEAD 10.5 
PREFETCHSIZE 8 
TRANSFERRATE 0.14 
BUFFERPOOL CARS_MDC_BP_DATA
DROPPED TABLE RECOVERY OFF;

CREATE LARGE TABLESPACE CARS_MDC_INDEX 
PAGESIZE 4 K  
MANAGED BY DATABASE  
USING ( FILE 'C:\DB2\CARS_MDC_INDEX_CONTAINER1.DBF' 15M ) 
EXTENTSIZE 2 
OVERHEAD 10.5 
PREFETCHSIZE 8 
TRANSFERRATE 0.14 
BUFFERPOOL CARS_MDC_BP_INDEX
DROPPED TABLE RECOVERY OFF;

--------------------------------
-- CREATE CARS TABLES         --
--------------------------------

ECHO -;
ECHO -------------------------;
ECHO Creating CARS Tables...;
ECHO -------------------------;

CREATE TABLE CARS
	(CARNAME	CHAR(20) NOT NULL,
	 COLOR		CHAR(10) NOT NULL,
	 YEAR		CHAR(04) NOT NULL,
	 AVAILABLE  	SMALLINT)
	IN CARS_DATA INDEX IN CARS_INDEX;

CREATE INDEX CARS_CARNAME ON CARS(CARNAME) CLUSTER PCTFREE 10;
CREATE INDEX CARS_COLOR	 ON CARS(COLOR)   PCTFREE 10;
CREATE INDEX CARS_YEAR	 ON CARS(YEAR)    PCTFREE 10;

CREATE TABLE CARS_MDC
	(CARNAME	CHAR(20) NOT NULL,
	 COLOR		CHAR(10) NOT NULL,
	 YEAR		CHAR(04) NOT NULL,
	 AVAILABLE	SMALLINT)
	ORGANIZE BY DIMENSIONS (CARNAME, COLOR, YEAR)
	IN CARS_MDC_DATA INDEX IN CARS_MDC_INDEX;

DROP TABLE CARS_TIMING_CHECK;

CREATE TABLE CARS_TIMING_CHECK (
	ACTION			CHAR(10),
	TABLE_NAME		CHAR(8),
	VAR_USED		CHAR(10),
	START_TIME		TIMESTAMP,
	END_TIME		TIMESTAMP,
	TOTAL_MICROSCNDS	BIGINT)
	ORGANIZE BY (ACTION, TABLE_NAME)
	IN USERSPACE1;

COMMIT WORK;

ECHO -;
ECHO -------------------------;
ECHO End of CARS creation...;
ECHO -------------------------;
