-- ------------------------------------------------------------------- 
-- MDC Lab 10 - Create data generation procedure
-- ------------------------------------------------------------------- 
-- This script creates 1 stored procedure CARS_INSERT_ALL
--
-- This inserts identical record sets into both tables.  This
-- first stored procedure is run to populate both tables.
--

ECHO -@
ECHO -------------------------@
ECHO Creating CARS Example Stored procedures..@
ECHO -------------------------@

ECHO -@
ECHO -------------------------@
ECHO Creating CARS_INSERT_ALL Stored procedure..@
ECHO -------------------------@

DROP PROCEDURE CARS_INSERT_ALL@

CREATE PROCEDURE CARS_INSERT_ALL (
	IN i_TOTAL_RECORDS 	INTEGER, 
	IN i_CAR_COUNT 		INTEGER, 
	IN i_COLOR_COUNT 	INTEGER,
	IN i_YEAR_COUNT		INTEGER)

SPECIFIC CARS_INSERT_ALL
RESULT SETS 0
MODIFIES SQL DATA
LANGUAGE SQL

BEGIN
	DECLARE v_TOTAL_RECORDS	INTEGER DEFAULT 0;
	DECLARE v_CAR_COUNT	INTEGER DEFAULT 0;
	DECLARE v_COLOR_COUNT	INTEGER DEFAULT 0;
	DECLARE v_YEAR_COUNT	INTEGER DEFAULT 0;

	DECLARE v_LOOP1		INTEGER DEFAULT 1;
	DECLARE v_LOOP2		INTEGER DEFAULT 1;

	DECLARE v_CAR_RAND	INTEGER DEFAULT 0;
	DECLARE v_COLOR_RAND	INTEGER DEFAULT 0;
	DECLARE v_YEAR_RAND	INTEGER DEFAULT 0;
	DECLARE v_AVAIL_RAND	SMALLINT DEFAULT 0;

	DECLARE v_CAR_TEXT	VARCHAR(20) DEFAULT 'X';
	DECLARE v_COLOR_TEXT	VARCHAR(10) DEFAULT 'X';
	DECLARE v_YEAR_TEXT	CHAR(4)     DEFAULT 'X';

--	MAXIMUM RECORDS YOU CAN INSERT IS 250,000
	IF i_TOTAL_RECORDS <= 250000 THEN
   	    SET v_TOTAL_RECORDS = i_TOTAL_RECORDS;
	ELSE
	    SET v_TOTAL_RECORDS	= 1;
	END IF;

--	MAXIMUM DIFFERENT CARS IS 12
	IF  i_CAR_COUNT <= 12 THEN
	    SET v_CAR_COUNT	= i_CAR_COUNT;
	ELSE
	    SET v_CAR_COUNT	= 13;
	END IF;

--	MAXIMUM	DIFFERENT COLORS IS 12
	IF  i_COLOR_COUNT <= 12 THEN
	    SET v_COLOR_COUNT	= i_COLOR_COUNT;
	ELSE
	    SET v_COLOR_COUNT 	= 13;
	END IF;

--	MAXIMUM	DIFFERENT YEARS IS 5
	IF  i_YEAR_COUNT <= 5 THEN
	    SET v_YEAR_COUNT	= i_YEAR_COUNT;
	ELSE
	    SET v_YEAR_COUNT 	= 5;
	END IF;

WHILE 	v_LOOP1 <= v_TOTAL_RECORDS DO  

	-- GENERATE FAKE CAR DATA
	SET v_CAR_RAND = INT(rand() * v_CAR_COUNT);

	CASE v_CAR_RAND
	WHEN 0  THEN SET v_CAR_TEXT = 'VW BUG';
	WHEN 1  THEN SET v_CAR_TEXT = 'CORVETTE STING RAY';
	WHEN 2  THEN SET v_CAR_TEXT = 'FERRARI F40';
	WHEN 3  THEN SET v_CAR_TEXT = 'VIPER GTS';
	WHEN 4  THEN SET v_CAR_TEXT = 'LAMBORGHINI COUNTACH';
	WHEN 5  THEN SET v_CAR_TEXT = 'GT-40';
	WHEN 6  THEN SET v_CAR_TEXT = 'MIATA';
	WHEN 7  THEN SET v_CAR_TEXT = 'MINI COOPER';
	WHEN 8  THEN SET v_CAR_TEXT = 'PORCHE 911';
	WHEN 9  THEN SET v_CAR_TEXT = 'SHELBY COBRA';
	WHEN 10 THEN SET v_CAR_TEXT = 'JAGUAR E-TYPE';
	WHEN 11 THEN SET v_CAR_TEXT = 'MCLAREN F1';
	ELSE 	       SET v_CAR_TEXT = 'AMC PACER';
	END CASE;

	-- GENERATE FAKE COLOR DATA 
	SET v_COLOR_RAND = INT(rand() * v_COLOR_COUNT);

	CASE v_COLOR_RAND
	WHEN 0  THEN SET v_COLOR_TEXT = 'BROWN';
	WHEN 1  THEN SET v_COLOR_TEXT = 'RED';
	WHEN 2  THEN SET v_COLOR_TEXT = 'BLUE';
	WHEN 3  THEN SET v_COLOR_TEXT = 'GREEN';
	WHEN 4  THEN SET v_COLOR_TEXT = 'YELLOW';
	WHEN 5  THEN SET v_COLOR_TEXT = 'PURPLE';
	WHEN 6  THEN SET v_COLOR_TEXT = 'BLACK';
	WHEN 7  THEN SET v_COLOR_TEXT = 'SILVER';
	WHEN 8  THEN SET v_COLOR_TEXT = 'GREY';
	WHEN 9  THEN SET v_COLOR_TEXT = 'ORANGE';
	WHEN 10 THEN SET v_COLOR_TEXT = 'PINK';
	WHEN 11 THEN SET v_COLOR_TEXT = 'WHITE';
	ELSE 	     SET v_COLOR_TEXT = 'CLEAR';
	END CASE;

	-- GENERATE FAKE YEAR DATA
	SET v_YEAR_RAND = INT(rand() * v_YEAR_COUNT);
	SET v_YEAR_TEXT = CHAR(v_YEAR_RAND + 2002);

	-- GENERATE FAKE AVAILABLE AMOUNT DATA
	SET v_AVAIL_RAND = SMALLINT(rand() * 5);

	-- INSERT IT INTO BOTH TABLES
	INSERT INTO CARS VALUES (v_CAR_TEXT, v_COLOR_TEXT, v_YEAR_TEXT, v_AVAIL_RAND) WITH UR;
	INSERT INTO CARS_MDC VALUES (v_CAR_TEXT, v_COLOR_TEXT, v_YEAR_TEXT, v_AVAIL_RAND) WITH UR;
    

	-- COMMIT EVERY 10,000 INSERTS
	IF 	v_LOOP2 <= 10000 THEN
		SET v_LOOP2 = v_LOOP2 + 1;
	ELSE
		COMMIT;
		SET v_LOOP2 = 0;
	END IF;

    SET v_LOOP1 = v_LOOP1 + 1;

END WHILE;

END@


