-- ------------------------------------------------------------------- 
-- MDC Lab 10 - Create checking stored procedures
-- ------------------------------------------------------------------- 
-- This script creates 4 stored procedures.  They are:
-- CARS_INSERT_CHK, CARS_FETCH_CHK,
-- CARS_UPDATE_CHK and CARS_DELETE_CHK.  
--
-- The 4 stored procedures run checks against the various DML 
-- actions against those tables.  You will run these manually during
-- the lab exercises.
-- ------------------------------------------------------------------- 
-- ------------------------------------------------------------------- 

ECHO -@
ECHO ------------------------------------------@
ECHO Creating CARS_FETCH_CHK Stored procedure..@
ECHO ------------------------------------------@

DROP   PROCEDURE CARS_FETCH_CHK@

CREATE PROCEDURE CARS_FETCH_CHK (
		 IN i_COLOR CHAR(10) ) 
	
SPECIFIC CARS_FETCH_CHK
RESULT SETS 0
MODIFIES SQL DATA
LANGUAGE SQL

BEGIN	DECLARE v_START 	TIMESTAMP;
	DECLARE v_STOP  	TIMESTAMP;
	DECLARE v_TOTAL 	BIGINT;

	DECLARE v_START_MDC 	TIMESTAMP;
	DECLARE v_STOP_MDC  	TIMESTAMP;
	DECLARE v_TOTAL_MDC 	BIGINT;
	DECLARE v_COLOR	 	CHAR(10);
	DECLARE v_HOLD	 	CHAR(20);
	DECLARE v_ATEND	 	INTEGER DEFAULT 0;

	DECLARE v_CARS_CUR CURSOR 	FOR SELECT CARNAME FROM CARS WHERE COLOR = v_COLOR;
	DECLARE v_CARS_CUR_MDC CURSOR 	FOR SELECT CARNAME FROM CARS_MDC WHERE COLOR = v_COLOR;
	DECLARE CONTINUE HANDLER 	FOR NOT FOUND SET v_ATEND = 1;

	SET v_COLOR = UPPER(i_COLOR);

--	------------------------
--	SELECTING FROM CARS_MDC
--	------------------------
	SET v_ATEND = 0;
	OPEN v_CARS_CUR_MDC;

	SET v_START_MDC = CURRENT TIMESTAMP;
	loop2:
	LOOP
		FETCH v_CARS_CUR_MDC into v_HOLD;
		IF v_ATEND <> 0 THEN LEAVE loop2;
		END IF;
	END LOOP loop2;

	SET v_STOP_MDC  = CURRENT TIMESTAMP;
	SET v_TOTAL_MDC = TIMESTAMPDIFF(1, CHAR(v_STOP_MDC - v_START_MDC));	
	
	INSERT INTO CARS_TIMING_CHECK VALUES ('FETCH','CARS_MDC',v_COLOR,v_START_MDC, v_STOP_MDC, v_TOTAL_MDC);

--	--------------------
--	SELECTING FROM CARS
--	--------------------
	SET v_ATEND = 0;
	OPEN v_CARS_CUR;

	SET v_START = CURRENT TIMESTAMP;
	loop1:
	LOOP
		FETCH v_CARS_CUR into v_HOLD;
		IF v_ATEND <> 0 THEN LEAVE loop1;
		END IF;
	END LOOP loop1;
	
	SET v_STOP  = CURRENT TIMESTAMP;
	SET v_TOTAL = TIMESTAMPDIFF(1, CHAR(v_STOP - v_START));	

	INSERT INTO CARS_TIMING_CHECK VALUES ('FETCH','CARS',v_COLOR,v_START, v_STOP, v_TOTAL);
	
	COMMIT;

END@


-- ------------------------------------------------------------------- 
-- ------------------------------------------------------------------- 
ECHO -@
ECHO ------------------------------------------@
ECHO Creating CARS_DELETE_CHK Stored procedure @
ECHO ------------------------------------------@

DROP PROCEDURE CARS_DELETE_CHK@

CREATE PROCEDURE CARS_DELETE_CHK (
		     IN i_COLOR CHAR(10) ) 
	
SPECIFIC CARS_DELETE_CHK
RESULT SETS 0
MODIFIES SQL DATA
LANGUAGE SQL

BEGIN	DECLARE v_START 	TIMESTAMP;
	DECLARE v_STOP  	TIMESTAMP;
	DECLARE v_TOTAL 	BIGINT;

	DECLARE v_START_MDC 	TIMESTAMP;
	DECLARE v_STOP_MDC  	TIMESTAMP;
	DECLARE v_TOTAL_MDC 	BIGINT;
	DECLARE v_COLOR	 	CHAR(10);

	SET v_COLOR = UPPER(i_COLOR);

--	------------------------
--	DELETING FROM CARS_MDC
--	------------------------
	SET v_START_MDC = CURRENT TIMESTAMP;
	DELETE FROM CARS_MDC WHERE COLOR = v_COLOR;
	COMMIT;
	SET v_STOP_MDC  = CURRENT TIMESTAMP;
	SET v_TOTAL_MDC = TIMESTAMPDIFF(1, CHAR(v_STOP_MDC - v_START_MDC));	
	
	INSERT INTO CARS_TIMING_CHECK VALUES ('DELETE','CARS_MDC',v_COLOR,v_START_MDC, v_STOP_MDC, v_TOTAL_MDC);

--	------------------------
--	DELETING FROM CARS
--	------------------------
	SET v_START = CURRENT TIMESTAMP;
	DELETE FROM CARS WHERE COLOR = v_COLOR;
	COMMIT;
	SET v_STOP  = CURRENT TIMESTAMP;
	SET v_TOTAL = TIMESTAMPDIFF(1, CHAR(v_STOP - v_START));	

	INSERT INTO CARS_TIMING_CHECK VALUES ('DELETE','CARS',v_COLOR,v_START, v_STOP, v_TOTAL);

	COMMIT;

END@


-- ------------------------------------------------------------------- 
-- ------------------------------------------------------------------- 
ECHO -@
ECHO ------------------------------------------@
ECHO Creating CARS_UPDATE_CHK Stored procedure @
ECHO ------------------------------------------@

DROP PROCEDURE CARS_UPDATE_CHK@

CREATE PROCEDURE CARS_UPDATE_CHK (
		     IN i_COLOR CHAR(10) ) 
	
SPECIFIC CARS_UPDATE_CHK
RESULT SETS 0
MODIFIES SQL DATA
LANGUAGE SQL

BEGIN	DECLARE v_START 	TIMESTAMP;
	DECLARE v_STOP  	TIMESTAMP;
	DECLARE v_TOTAL 	BIGINT;

	DECLARE v_START_MDC 	TIMESTAMP;
	DECLARE v_STOP_MDC  	TIMESTAMP;
	DECLARE v_TOTAL_MDC 	BIGINT;
	DECLARE v_COLOR	 	CHAR(10);

	SET v_COLOR = UPPER(i_COLOR);

--	------------------------
--	UPDATING TO CARS_MDC
--	------------------------
	SET v_START_MDC = CURRENT TIMESTAMP;
	UPDATE CARS_MDC SET COLOR = 'X'||v_COLOR WHERE COLOR = v_COLOR;
	COMMIT;
	SET v_STOP_MDC  = CURRENT TIMESTAMP;
	SET v_TOTAL_MDC = TIMESTAMPDIFF(1, CHAR(v_STOP_MDC - v_START_MDC));	
	
	INSERT INTO CARS_TIMING_CHECK VALUES ('UPDATE','CARS_MDC',v_COLOR,v_START_MDC, v_STOP_MDC, v_TOTAL_MDC);

--	------------------------
--	UPDATING TO CARS
--	------------------------
	SET v_START = CURRENT TIMESTAMP;
	UPDATE CARS SET COLOR = 'X'||v_COLOR WHERE COLOR = v_COLOR;
	COMMIT;
	SET v_STOP  = CURRENT TIMESTAMP;
	SET v_TOTAL = TIMESTAMPDIFF(1, CHAR(v_STOP - v_START));	

	INSERT INTO CARS_TIMING_CHECK VALUES ('UPDATE','CARS',v_COLOR,v_START, v_STOP, v_TOTAL);

	COMMIT;

END@


-- ------------------------------------------------------------------- 
-- ------------------------------------------------------------------- 
ECHO -@
ECHO ------------------------------------------@
ECHO Creating CARS_INSERT_CHK Stored procedure @
ECHO ------------------------------------------@

DROP PROCEDURE CARS_INSERT_CHK@

CREATE PROCEDURE CARS_INSERT_CHK (
		 IN i_COLOR CHAR(10) ) 
	
SPECIFIC CARS_INSERT_CHK
RESULT SETS 0
MODIFIES SQL DATA
LANGUAGE SQL

BEGIN	DECLARE v_START 	TIMESTAMP;
	DECLARE v_STOP  	TIMESTAMP;
	DECLARE v_TOTAL 	BIGINT;

	DECLARE v_START_MDC 	TIMESTAMP;
	DECLARE v_STOP_MDC  	TIMESTAMP;
	DECLARE v_TOTAL_MDC 	BIGINT;
	DECLARE v_COLOR	 	CHAR(10);

	SET v_COLOR = UPPER(i_COLOR);

--	------------------------
--	INSERTING TO CARS_MDC
--	------------------------
	SET v_START_MDC = CURRENT TIMESTAMP;
	INSERT INTO CARS_MDC VALUES ('VW BUG',v_COLOR,'1999',99);
	COMMIT;
	SET v_STOP_MDC  = CURRENT TIMESTAMP;
	SET v_TOTAL_MDC = TIMESTAMPDIFF(1, CHAR(v_STOP_MDC - v_START_MDC));	
	
	INSERT INTO CARS_TIMING_CHECK VALUES ('INSERT','CARS_MDC',v_COLOR,v_START_MDC, v_STOP_MDC, v_TOTAL_MDC);

--	------------------------
--	INSERTING TO CARS
--	------------------------
	SET v_START = CURRENT TIMESTAMP;
	INSERT INTO CARS VALUES ('VW BUG',v_COLOR,'1999',99);
	COMMIT;
	SET v_STOP  = CURRENT TIMESTAMP;
	SET v_TOTAL = TIMESTAMPDIFF(1, CHAR(v_STOP - v_START));	

	INSERT INTO CARS_TIMING_CHECK VALUES ('INSERT','CARS',v_COLOR,v_START, v_STOP, v_TOTAL);
	COMMIT;
END@