-- ------------------------------------------------------------------- 
-- DB2 PoT - 11 Design Advisor - Create TPCD Database
-- ------------------------------------------------------------------- 

CONNECT TO TPCD;

CREATE TABLE TPCD.REGION  (
  	  R_REGIONKEY INTEGER NOT NULL , 
  	  R_NAME CHAR(25) NOT NULL)
  	  IN SMS;
     
ALTER TABLE TPCD.REGION LOCKSIZE TABLE;


CREATE TABLE TPCD.NATION  (
  	  N_NATIONKEY INTEGER NOT NULL , 
  	  N_NAME CHAR(25) NOT NULL , 
  	  N_REGIONKEY INTEGER NOT NULL)
   	  IN SMS;

ALTER TABLE TPCD.NATION LOCKSIZE TABLE;


CREATE INDEX TPCD.N_RK ON TPCD.NATION 
		(N_REGIONKEY ASC)
		PCTFREE 0;
    
ALTER TABLE TPCD.NATION 
	ADD CONSTRAINT PK PRIMARY KEY
		(N_NATIONKEY);
      

CREATE TABLE TPCD.PART  (
  	  P_PARTKEY INTEGER NOT NULL , 
  	  P_NAME VARCHAR(55) NOT NULL , 
  	  P_MFGR CHAR(25) NOT NULL , 
  	  P_BRAND CHAR(10) NOT NULL , 
  	  P_TYPE VARCHAR(25) NOT NULL , 
  	  P_SIZE INTEGER NOT NULL , 
  	  P_CONTAINER CHAR(10) NOT NULL , 
  	  P_RETAILPRICE DOUBLE NOT NULL)
 	  IN SMS;
      
ALTER TABLE TPCD.PART LOCKSIZE TABLE;


CREATE UNIQUE INDEX TPCD.P_PK ON TPCD.PART 
  	(P_PARTKEY ASC)
  	PCTFREE 0;
   

CREATE TABLE TPCD.PARTSUPP  (
  	  PS_PARTKEY INTEGER NOT NULL , 
  	  PS_SUPPKEY INTEGER NOT NULL , 
  	  PS_AVAILQTY INTEGER NOT NULL , 
  	  PS_SUPPLYCOST DOUBLE NOT NULL)
 	  IN SMS;
      
ALTER TABLE TPCD.PARTSUPP LOCKSIZE TABLE;


CREATE INDEX TPCD.PS_PK ON TPCD.PARTSUPP 
  	(PS_PARTKEY ASC)
  	PCTFREE 0;
   

CREATE UNIQUE INDEX TPCD.PS_PK_SK ON TPCD.PARTSUPP 
  	(PS_PARTKEY ASC,
  	 PS_SUPPKEY ASC)
  	PCTFREE 0;
   

CREATE INDEX TPCD.PS_SK ON TPCD.PARTSUPP 
  	(PS_SUPPKEY ASC)
  	PCTFREE 0;
   

CREATE TABLE TPCD.LINEITEM  (
  	  L_ORDERKEY BIGINT NOT NULL , 
  	  L_PARTKEY INTEGER NOT NULL , 
  	  L_SUPPKEY INTEGER NOT NULL , 
  	  L_LINENUMBER INTEGER NOT NULL , 
  	  L_QUANTITY DOUBLE NOT NULL , 
  	  L_EXTENDEDPRICE DOUBLE NOT NULL , 
  	  L_DISCOUNT DOUBLE NOT NULL , 
  	  L_TAX DOUBLE NOT NULL , 
  	  L_RETURNFLAG CHAR(1) NOT NULL , 
  	  L_LINESTATUS CHAR(1) NOT NULL , 
  	  L_SHIPDATE DATE NOT NULL , 
  	  L_COMMITDATE DATE NOT NULL , 
  	  L_RECEIPTDATE DATE NOT NULL , 
  	  L_SHIPINSTRUCT CHAR(25) NOT NULL , 
  	  L_SHIPMODE CHAR(10) NOT NULL)
  	   IN SMS;
      
ALTER TABLE TPCD.LINEITEM APPEND ON;



CREATE INDEX TPCD.L_OK ON TPCD.LINEITEM 
  	(L_ORDERKEY ASC)
  	PCTFREE 3;
   

CREATE INDEX TPCD.L_PK ON TPCD.LINEITEM 
  	(L_PARTKEY ASC)
  	PCTFREE 3;
   

CREATE INDEX TPCD.L_PK_SK ON TPCD.LINEITEM 
  	(L_PARTKEY ASC,
  	 L_SUPPKEY ASC)
  	PCTFREE 3;
   

CREATE INDEX TPCD.L_RD ON TPCD.LINEITEM 
  	(L_RECEIPTDATE ASC)
  	PCTFREE 3;
   

CREATE INDEX TPCD.L_SD ON TPCD.LINEITEM 
  	(L_SHIPDATE ASC)
  	PCTFREE 3;
   

CREATE TABLE TPCD.ORDERS  (
  	  O_ORDERKEY BIGINT NOT NULL , 
  	  O_CUSTKEY INTEGER NOT NULL , 
  	  O_ORDERSTATUS CHAR(1) NOT NULL , 
  	  O_TOTALPRICE DOUBLE NOT NULL , 
  	  O_ORDERDATE DATE NOT NULL , 
  	  O_ORDERPRIORITY CHAR(15) NOT NULL , 
  	  O_CLERK CHAR(15) NOT NULL , 
  	  O_SHIPPRIORITY INTEGER NOT NULL)
  	  IN SMS;
      
ALTER TABLE TPCD.ORDERS APPEND ON;


CREATE INDEX TPCD.O_CK ON TPCD.ORDERS 
  	(O_CUSTKEY ASC)
  	PCTFREE 3;
   

CREATE INDEX TPCD.O_OD ON TPCD.ORDERS 
  	(O_ORDERDATE ASC)
  	PCTFREE 3;
   

CREATE UNIQUE INDEX TPCD.O_OK ON TPCD.ORDERS 
  	(O_ORDERKEY ASC)
  	PCTFREE 3;
   

CREATE TABLE TPCD.SUPPLIER  (
  	  S_SUPPKEY INTEGER NOT NULL , 
  	  S_NAME CHAR(25) NOT NULL , 
  	  S_ADDRESS VARCHAR(40) NOT NULL , 
  	  S_NATIONKEY INTEGER NOT NULL , 
  	  S_PHONE CHAR(15) NOT NULL , 
  	  S_ACCTBAL DOUBLE NOT NULL)
  	  IN SMS;
   
ALTER TABLE TPCD.SUPPLIER LOCKSIZE TABLE;


CREATE INDEX TPCD.S_NK ON TPCD.SUPPLIER 
  	(S_NATIONKEY ASC)
  	PCTFREE 0;
   

CREATE UNIQUE INDEX TPCD.S_SK ON TPCD.SUPPLIER 
  	(S_SUPPKEY ASC)
  	PCTFREE 0;
   

CREATE TABLE TPCD.CUSTOMER  (
  	  C_CUSTKEY INTEGER NOT NULL , 
  	  C_NAME VARCHAR(25) NOT NULL , 
  	  C_ADDRESS VARCHAR(40) NOT NULL , 
  	  C_NATIONKEY INTEGER NOT NULL , 
  	  C_PHONE CHAR(15) NOT NULL , 
  	  C_ACCTBAL DOUBLE NOT NULL , 
  	  C_MKTSEGMENT CHAR(10) NOT NULL)
  	  IN SMS;
      
ALTER TABLE TPCD.CUSTOMER LOCKSIZE TABLE;


CREATE UNIQUE INDEX TPCD.C_CK ON TPCD.CUSTOMER 
  	(C_CUSTKEY ASC)
  	PCTFREE 0;
   
ALTER TABLE TPCD.CUSTOMER 
  ADD CONSTRAINT PK PRIMARY KEY
  	(C_CUSTKEY);

   
CONNECT RESET;
