--#SET FREQUENCY 1
select
	l_returnflag,
	l_linestatus,
	sum(l_quantity) as sum_qty,
	sum(l_extendedprice) as sum_base_price,
	sum(l_extendedprice * (1 - l_discount)) as sum_disc_price,
	sum(l_extendedprice * (1 - l_discount) * (1 + l_tax)) as sum_charge,
	avg(l_quantity) as avg_qty,
	avg(l_extendedprice) as avg_price,
	avg(l_discount) as avg_disc,
	count(*) as count_order
from
	tpcd.lineitem
where
	l_shipdate <= date ('1998-12-01') - 90 day
group by
	l_returnflag,
	l_linestatus
order by
	l_returnflag,
	l_linestatus;

--#SET FREQUENCY 1
select s_acctbal,s_name,n_name,p_partkey,p_mfgr,s_address,s_phone
from tpcd.part,tpcd.supplier,tpcd.partsupp,tpcd.nation,tpcd.region
where p_partkey = ps_partkey
	and s_suppkey = ps_suppkey
	and p_size = 15
	and p_type like '%BRASS'
	and s_nationkey = n_nationkey
	and n_regionkey = r_regionkey
	and r_name = 'EUROPE'
	and ps_supplycost = (
		select min(ps_supplycost)
		from tpcd.partsupp,tpcd.supplier,tpcd.nation,tpcd.region
		where p_partkey = ps_partkey
			and s_suppkey = ps_suppkey
			and s_nationkey = n_nationkey
			and n_regionkey = r_regionkey
			and r_name = 'EUROPE'
	)
order by s_acctbal desc,n_name,s_name,p_partkey;

--#SET FREQUENCY 1
select
	l_orderkey,
	sum(l_extendedprice * (1 - l_discount)) as revenue,
	o_orderdate,
	o_shippriority
from
	tpcd.customer,
	tpcd.orders,
	tpcd.lineitem
where
	c_mktsegment = 'BUILDING'
	and c_custkey = o_custkey
	and l_orderkey = o_orderkey
	and o_orderdate < date ('1995-03-15')
	and l_shipdate > date ('1995-03-15')
group by
	l_orderkey,
	o_orderdate,
	o_shippriority
order by
	revenue desc,
	o_orderdate;

--#SET FREQUENCY 1
select
	o_orderpriority,
	count(*) as order_count
from
	tpcd.orders
where
	o_orderdate >= date ('1993-07-01')
	and o_orderdate < date ('1993-07-01') + 3 month
	and exists (
		select
			*
		from
			tpcd.lineitem
		where
			l_orderkey = o_orderkey
			and l_commitdate < l_receiptdate
	)
group by
	o_orderpriority
order by
	o_orderpriority;

--#SET FREQUENCY 1
select n_name, sum(l_extendedprice * (1 - l_discount)) as revenue
from tpcd.customer,tpcd.orders,tpcd.lineitem,tpcd.supplier,tpcd.nation,tpcd.region
where   c_custkey = o_custkey
	and o_orderkey = l_orderkey
	and l_suppkey = s_suppkey
	and c_nationkey = s_nationkey
	and s_nationkey = n_nationkey
	and n_regionkey = r_regionkey
	and r_name = 'ASIA'
	and o_orderdate >= date ('1994-01-01')
	and o_orderdate < date ('1994-01-01') + 1 year
group by n_name
order by revenue desc;

--#SET FREQUENCY 1
select
	sum(l_extendedprice * l_discount) as revenue
from
	tpcd.lineitem
where
	l_shipdate >= date ('1994-01-01')
	and l_shipdate < date ('1994-01-01') + 1 year
	and l_discount between .06 - 0.01 and .06 + 0.01
	and l_quantity < 24;
--#SET FREQUENCY 1
select supp_nation, cust_nation,l_year,sum(volume) as revenue
from (select n1.n_name as supp_nation, n2.n_name as cust_nation,
	year (l_shipdate) as l_year, l_extendedprice * (1 - l_discount) as volume
	from tpcd.supplier, tpcd.lineitem,tpcd.orders,tpcd.customer,tpcd.nation n1,
			tpcd.nation n2
		where   s_suppkey = l_suppkey
			and o_orderkey = l_orderkey
			and c_custkey = o_custkey
			and s_nationkey = n1.n_nationkey
			and c_nationkey = n2.n_nationkey
			and (
				(n1.n_name = 'FRANCE' and n2.n_name = 'GERMANY')
				or (n1.n_name = 'GERMANY' and n2.n_name = 'FRANCE')
			)
			and l_shipdate between date('1995-01-01') and date('1996-12-31')
	) as shipping
group by supp_nation, cust_nation,l_year
order by supp_nation,cust_nation,l_year;
--#SET FREQUENCY 1
select	o_year,	sum(case
		when nation = 'BRAZIL' then volume
		else 0
	end) / sum(volume) as mkt_share
from	(	select	year(o_orderdate) as o_year,
			l_extendedprice * (1 - l_discount) as volume,
			n2.n_name as nation
		from	tpcd.part,tpcd.supplier,tpcd.lineitem,tpcd.orders,tpcd.customer,
			tpcd.nation n1,tpcd.nation n2,tpcd.region
		where	p_partkey = l_partkey
			and s_suppkey = l_suppkey
			and l_orderkey = o_orderkey
			and o_custkey = c_custkey
			and c_nationkey = n1.n_nationkey
			and n1.n_regionkey = r_regionkey
			and r_name = 'AMERICA'
			and s_nationkey = n2.n_nationkey
			and o_orderdate between date('1995-01-01') and date ('1996-12-31')
			and p_type = 'ECONOMY ANODIZED STEEL'
	) as all_nations
group by	o_year
order by	o_year;

--#SET FREQUENCY 1
select nation,o_year,sum(amount) as sum_profit
from ( select n_name as nation, year(o_orderdate) as o_year,
			l_extendedprice * (1 - l_discount) - ps_supplycost * l_quantity as amount
		from tpcd.part, tpcd.supplier,tpcd.lineitem,tpcd.partsupp,
			tpcd.orders, tpcd.nation
		where s_suppkey = l_suppkey
			and ps_suppkey = l_suppkey
			and ps_partkey = l_partkey
			and p_partkey = l_partkey
			and o_orderkey = l_orderkey
			and s_nationkey = n_nationkey
			and p_name like '%green%'
	) as profit
group by nation, o_year
order by nation, o_year desc;

--#SET FREQUENCY 1
select c_custkey,c_name,sum(l_extendedprice * (1 - l_discount)) as revenue,
	c_acctbal,n_name,c_address,c_phone
from tpcd.customer,tpcd.orders,tpcd.lineitem,tpcd.nation
where
	c_custkey = o_custkey
	and l_orderkey = o_orderkey
	and o_orderdate >= date ('1993-10-01')
	and o_orderdate < date ('1993-10-01') + 3 month
	and l_returnflag = 'R'
	and c_nationkey = n_nationkey
group by
	c_custkey,
	c_name,
	c_acctbal,
	c_phone,
	n_name,
	c_address
order by
	revenue desc;

--#SET FREQUENCY 1
select ps_partkey, sum(ps_supplycost * ps_availqty) as value
from tpcd.partsupp, tpcd.supplier, tpcd.nation
where ps_suppkey = s_suppkey and s_nationkey = n_nationkey and n_name = 'GERMANY'
group by ps_partkey having sum(ps_supplycost * ps_availqty) > (
			select sum(ps_supplycost * ps_availqty) * 0.0000010000
			from tpcd.partsupp, tpcd.supplier, tpcd.nation
			where ps_suppkey = s_suppkey
				and s_nationkey = n_nationkey
				and n_name = 'GERMANY'
		)
order by value desc;

--#SET FREQUENCY 1
select
	l_shipmode,
	sum(case
		when o_orderpriority = '1-URGENT'
			or o_orderpriority = '2-HIGH'
			then 1
		else 0
	end) as high_line_count,
	sum(case
		when o_orderpriority <> '1-URGENT'
			and o_orderpriority <> '2-HIGH'
			then 1
		else 0
	end) as low_line_count
from
	tpcd.orders,
	tpcd.lineitem
where
	o_orderkey = l_orderkey
	and l_shipmode in ('MAIL', 'SHIP')
	and l_commitdate < l_receiptdate
	and l_shipdate < l_commitdate
	and l_receiptdate >= date ('1994-01-01')
	and l_receiptdate < date ('1994-01-01') + 1 year
group by
	l_shipmode
order by
	l_shipmode;

--#SET FREQUENCY 1
select
	c_count,
	count(*) as custdist
from
	(
		select
			c_custkey,
			count(o_orderkey)
		from
			tpcd.customer left outer join tpcd.orders on
				c_custkey = o_custkey
				--and o_comment not like '%special%requests%'
		group by
			c_custkey
	) as c_orders (c_custkey, c_count)
group by
	c_count
order by
	custdist desc,
	c_count desc;
--#SET FREQUENCY 1
select
	100.00 * sum(case
		when p_type like 'PROMO%'
			then l_extendedprice * (1 - l_discount)
		else 0
	end) / sum(l_extendedprice * (1 - l_discount)) as promo_revenue
from
	tpcd.lineitem,
	tpcd.part
where
	l_partkey = p_partkey
	and l_shipdate >= date ('1995-09-01')
	and l_shipdate < date ('1995-09-01') + 1 month;
--#SET FREQUENCY 1
with revenue (supplier_no, total_revenue) as (
		select l_suppkey,sum(l_extendedprice * (1-l_discount))
		from tpcd.lineitem
		where l_shipdate >= date ('1996-01-01')
			and l_shipdate < date ('1996-01-01') + 3 month
		group by l_suppkey
)

select s_suppkey,s_name,s_address,s_phone,total_revenue
from tpcd.supplier,revenue
where s_suppkey = supplier_no
	and total_revenue = (
		select max(total_revenue)
		from revenue
	)
order by s_suppkey;
--#SET FREQUENCY 1
select p_brand, p_type, p_size, count(distinct ps_suppkey) as supplier_cnt
from tpcd.partsupp, tpcd.part
where p_partkey = ps_partkey
	and p_brand <> 'Brand#45'
	and p_type not like 'MEDIUM POLISHED%'
	and p_size in (49, 14, 23, 45, 19, 3, 36, 9)
	and ps_suppkey not in (
		select
			s_suppkey
		from
			tpcd.supplier
		--where
		--	s_comment like '%Customer%Complaints%'
	)
group by p_brand, p_type, p_size
order by
	supplier_cnt desc,
	p_brand,
	p_type,
	p_size;

--#SET FREQUENCY 1
select
	sum(l_extendedprice) / 7.0 as avg_yearly
from
	tpcd.lineitem,
	tpcd.part
where
	p_partkey = l_partkey
	and p_brand = 'Brand#23'
	and p_container = 'MED BOX'
	and l_quantity < (
		select
			0.2 * avg(l_quantity)
		from
			tpcd.lineitem
		where
			l_partkey = p_partkey
	);
--#SET FREQUENCY 1
select c_name, c_custkey,o_orderkey,o_orderdate,o_totalprice,sum(l_quantity)
from tpcd.customer,tpcd.orders,tpcd.lineitem
where o_orderkey in ( select l_orderkey
		from tpcd.lineitem
		group by l_orderkey having sum(l_quantity) > 300
	)
	and c_custkey = o_custkey
	and o_orderkey = l_orderkey
group by c_name, c_custkey, o_orderkey, o_orderdate, o_totalprice
order by o_totalprice desc,o_orderdate;

--#SET FREQUENCY 1
select sum(l_extendedprice* (1 - l_discount)) as revenue
from tpcd.lineitem, tpcd.part
where ( p_partkey = l_partkey
		and p_brand = 'Brand#12'
		and p_container in ('SM CASE', 'SM BOX', 'SM PACK', 'SM PKG')
		and l_quantity >= 1 and l_quantity <= 1 + 10
		and p_size between 1 and 5
		and l_shipmode in ('AIR', 'AIR REG')
		and l_shipinstruct = 'DELIVER IN PERSON'
	)
	or ( p_partkey = l_partkey
		and p_brand = 'Brand#23'
		and p_container in ('MED BAG', 'MED BOX', 'MED PKG', 'MED PACK')
		and l_quantity >= 10 and l_quantity <= 10 + 10
		and p_size between 1 and 10
		and l_shipmode in ('AIR', 'AIR REG')
		and l_shipinstruct = 'DELIVER IN PERSON'
	)
	or ( p_partkey = l_partkey
		and p_brand = 'Brand#34'
		and p_container in ('LG CASE', 'LG BOX', 'LG PACK', 'LG PKG')
		and l_quantity >= 20 and l_quantity <= 20 + 10
		and p_size between 1 and 15
		and l_shipmode in ('AIR', 'AIR REG')
		and l_shipinstruct = 'DELIVER IN PERSON'
	);

--#SET FREQUENCY 1
select s_name, s_address
from tpcd.supplier, tpcd.nation
where	s_suppkey in (
		select ps_suppkey
		from tpcd.partsupp
		where ps_partkey in (
				select	p_partkey
				from tpcd.part
				where p_name like 'forest%'
			)
			and ps_availqty > (
				select 0.5 * sum(l_quantity)
				from tpcd.lineitem
				where   l_partkey = ps_partkey
					and l_suppkey = ps_suppkey
					and l_shipdate >= date ('1994-01-01')
					and l_shipdate < date ('1994-01-01') + 1 year
			)
	)
	and s_nationkey = n_nationkey
	and n_name = 'CANADA'
order by s_name;
--#SET FREQUENCY 1
select s_name, count(*) as numwait
from tpcd.supplier, tpcd.lineitem l1, tpcd.orders, tpcd.nation
where s_suppkey = l1.l_suppkey
	and o_orderkey = l1.l_orderkey
	and o_orderstatus = 'F'
	and l1.l_receiptdate > l1.l_commitdate
	and exists (
		select *
		from tpcd.lineitem l2
		where   l2.l_orderkey = l1.l_orderkey
			and l2.l_suppkey <> l1.l_suppkey
	)
	and not exists (
		select *
		from tpcd.lineitem l3
		where l3.l_orderkey = l1.l_orderkey
			and l3.l_suppkey <> l1.l_suppkey
			and l3.l_receiptdate > l3.l_commitdate
	)
	and s_nationkey = n_nationkey
	and n_name = 'SAUDI ARABIA'
group by s_name
order by numwait desc, s_name;

--#SET FREQUENCY 1
select	cntrycode, count(*) as numcust, sum(c_acctbal) as totacctbal
from	(select substr(c_phone, 1, 2) as cntrycode, c_acctbal
		from tpcd.customer
		where substr(c_phone, 1, 2) in ('13', '31', '23', '29', '30', '18', '17')
			and c_acctbal > (
				select avg(c_acctbal)
				from tpcd.customer
				where   c_acctbal > 0.00
					and substr(c_phone, 1, 2) in
						('13', '31', '23', '29', '30', '18', '17')
			)
			and not exists (
				select *
				from tpcd.orders
				where o_custkey = c_custkey
			)
	) as custsale
group by cntrycode
order by cntrycode;
