::  DB2 9.7 Admin for Experienced DBAs
::  Copyright(r) IBM Corporation
::
::  Vikram Khatri (vikram.khatri@us.ibm.com)
::

REM ------------------------------------------------------------------- 
REM DEMONSTRATE THE RECOVERY OF A DROPPED TABLE                                                
REM ------------------------------------------------------------------- 

TITLE Backup08.CMD - Recover Dropped Table

SET OUTFILE=%~n0_OUTPUT.TXT

@echo off
cls

ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% %TIME% 
ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% %TIME% > %OUTFILE%
ECHO.
ECHO ---------------------------------------------------------------------
ECHO DEMONSTRATE HOW TO RECOVER A DROPPED TABLE
ECHO ---------------------------------------------------------------------
ECHO.
ECHO.
ECHO =====================================================================
ECHO  Step - 1: TAKE AN ONLINE BACKUP OF THE DATABASE 
ECHO            (To level set this exercise)
ECHO =====================================================================
ECHO.

db2 BACKUP DATABASE BKPTEST ONLINE TO "C:\DB2Backup" COMPRESS  UTIL_IMPACT_PRIORITY 50 WITHOUT PROMPTING >> %OUTFILE%

ECHO.
ECHO =====================================================================
ECHO  Step - 2: CREATE A TABLE, INSERT THE DATA AND DROP THE TABLE 
ECHO            (to simulate the loss of a table)
ECHO =====================================================================
ECHO.

db2 connect to bkptest  				>> %OUTFILE%
db2 CREATE TABLE RECOVERME^
(^
   RECOVERME_ID   INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH 100000, INCREMENT BY 5),^
   SSN            CHAR(11) NOT NULL,^
   FIRST_NAME     VARCHAR(20) NOT NULL,^
   LAST_NAME      VARCHAR(20) NOT NULL,^
   job_code       CHAR(4) NOT NULL,^
   dept           SMALLINT NOT NULL,^
   salary         DECIMAL(12,2) NOT NULL,^
   DOB            DATE NOT NULL WITH DEFAULT,^
   CONSTRAINT pk_recoverme PRIMARY KEY (RECOVERME_ID)^
) in HDATA16 index in HIDX16 				>> %OUTFILE%
db2 CONNECT RESET 					>> %OUTFILE%

db2 -tf Backup48.DDL 					>> %OUTFILE%

db2 connect to bkptest  				>> %OUTFILE%
db2 drop table recoverme 				>> %OUTFILE%
db2 CONNECT RESET 					>> %OUTFILE%


ECHO.
ECHO =====================================================================
ECHO  Step - 3: See history of dropped table
ECHO            (To find that lost table)
ECHO =====================================================================
ECHO.

ECHO. 							>>  %OUTFILE%
ECHO --------------------------------------------------------------------- >>  %OUTFILE%
ECHO HISTORY OF DROPPED TABLE BEGINS HERE 		>>  %OUTFILE%

db2 list history dropped table all for bkptest 		>>  %OUTFILE%

ECHO HISTORY OF DROPPED TABLE ENDS HERE 		>>  %OUTFILE%
ECHO --------------------------------------------------------------------- >>  %OUTFILE%
ECHO. 							>>  %OUTFILE%


ECHO.
ECHO =====================================================================
ECHO  Step - 4: Restore tablespace HDATA16,HIDX16 ONLINE 
ECHO            (from last full backup)
ECHO =====================================================================
ECHO.

FOR /F "tokens=1" %%K in ('call Backup22.bat') do SET TIMESTAMP=%%K

ECHO STARTING RESTORE OF TABLESPACE(HDATA16,HIDX16) IN BKPTEST DATABASE FOR TIMESTAMP %timestamp% >> %OUTFILE%

db2 RESTORE DATABASE BKPTEST TABLESPACE(HDATA16,HIDX16) ONLINE FROM "c:\db2backup" TAKEN AT %timestamp% WITHOUT PROMPTING >> %OUTFILE%

ECHO.
ECHO =====================================================================
ECHO  Step - 5: Unload dropped table data using TABLEID from dropped table 
ECHO            history (to get data)
ECHO =====================================================================
ECHO.

FOR /F "tokens=1" %%K in ('call Backup23.bat') do SET TABLEID=%%K

ECHO ECHO RECOVERING DROPPED TABLE ID %tableid% DATA TO c:\db2backup >> %OUTFILE%

db2 rollforward database BKPTEST to end of logs and complete tablespace(HDATA16,HIDX16) online recover dropped table %tableid% to "c:\db2backup" >> %OUTFILE%

ECHO.
ECHO =====================================================================
ECHO  Step - 6: RE-CREATE TABLE USING DDL (this can be found in the 
ECHO            history file, but here we just put the DDL in the script)
ECHO =====================================================================
ECHO.

db2 connect to bkptest  				>> %OUTFILE%
db2 CREATE TABLE RECOVERME^
(^
   RECOVERME_ID   INTEGER NOT NULL GENERATED BY DEFAULT AS IDENTITY (START WITH 100000, INCREMENT BY 5),^
   SSN            CHAR(11) NOT NULL,^
   FIRST_NAME     VARCHAR(20) NOT NULL,^
   LAST_NAME      VARCHAR(20) NOT NULL,^
   job_code       CHAR(4) NOT NULL,^
   dept           SMALLINT NOT NULL,^
   salary         DECIMAL(12,2) NOT NULL,^
   DOB            DATE NOT NULL WITH DEFAULT,^
   CONSTRAINT pk_strawman PRIMARY KEY (RECOVERME_ID)^
) in HDATA16 index in HIDX16 				>> %OUTFILE%


ECHO.
ECHO =====================================================================
ECHO  Step - 7: LOAD DATA IN TABLE
ECHO =====================================================================
ECHO.

db2 load from "c:\db2backup\node0000\data" OF DEL METHOD p(1,2,3,4,5,6,7,8) insert into recoverme nonrecoverable >> %OUTFILE%

db2 "select count(*) RECOVERME from recoverme"
db2 "select count(*) RECOVERME from recoverme"		>> %OUTFILE%
db2 connect reset  					>> %OUTFILE%

ECHO.
ECHO ---------------------------------------------------------------------
ECHO Note: Restoring dropped table involved 7 different steps, but step 5 
ECHO       and 6 are the keys to this exercise.  Please review each step 
ECHO       carefully.  Check the OUTPUT FILE '%OUTFILE%'
ECHO ---------------------------------------------------------------------
ECHO.