::  DB2 9.7 Admin for Experienced DBAs
::  Copyright(r) IBM Corporation
::
::  Vikram Khatri (vikram.khatri@us.ibm.com)
::

REM ------------------------------------------------------------------- 
REM INCREMENTAL ONLINE BACKUP / RESTORE / RECOVERY OF TABLE SPACES                                               
REM ------------------------------------------------------------------- 

TITLE Backup12.CMD - Incremental backup and restore

SET OUTFILE=%~n0_OUTPUT.TXT

@echo off
cls


ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% %TIME% 
ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% %TIME% > %OUTFILE%
ECHO.
ECHO ---------------------------------------------------------------------
ECHO INCREMENTAL ONLINE BACKUP / RESTORE / RECOVERY OF TABLE SPACES  
ECHO ---------------------------------------------------------------------
ECHO.

ECHO.
ECHO =====================================================================
ECHO Step 1: CHECKING TRACKMOD PARAMETER TO ALLOW INCREMENTAL BACKUPS
ECHO =====================================================================
ECHO.

REM
REM CHECK FOR TRACKMOD FOR BKPTEST DATABASE
REM IF NOT SET, SET THIS PARAMETER 

FOR /F "tokens=6" %%K in ('db2 get db cfg for bkptest ^| findstr /I /C:"trackmod"') do SET TRACKMOD=%%K >> %OUTFILE%
IF "%TRACKMOD%" NEQ "ON " (
   ECHO TRACKMOD IS NOT SET FOR BKPTEST DATABASE. SETTING IT NOW.
   db2 update db cfg for bkptest using trackmod on 		>> %OUTFILE%
   db2 terminate 						>> %OUTFILE%
)

ECHO.
ECHO =====================================================================
ECHO Step 2: Create 1000 rows in table: BACKUPTEST
ECHO =====================================================================
ECHO.

db2 connect to bkptest 						>> %OUTFILE%
db2 delete from backuptest 					>> %OUTFILE%
db2 connect reset 						>> %OUTFILE%

db2 -tvf Backup51.DDL 						>> %OUTFILE%

ECHO.
ECHO =====================================================================
ECHO Step 3: TAKE FULL ONLINE BACKUP OF BKPTEST DATABASE
ECHO =====================================================================
ECHO.

db2 BACKUP DATABASE BKPTEST ONLINE TO "C:\DB2Backup" COMPRESS  UTIL_IMPACT_PRIORITY 50 WITHOUT PROMPTING >> %OUTFILE%

ECHO.
ECHO =====================================================================
ECHO Step 4: Create another 1000 rows in table: BACKUPTEST
ECHO =====================================================================
ECHO.

db2 -tvf Backup51.DDL 						>> %OUTFILE%

ECHO.
ECHO =====================================================================
ECHO Step 5: TAKE 1st INCREMENTAL BACKUP OF BKPTEST DATABASE
ECHO         (Key 1st step in this exercise)
ECHO =====================================================================
ECHO.

db2 backup database bkptest ONLINE incremental to c:\db2backup COMPRESS  UTIL_IMPACT_PRIORITY 50 WITHOUT PROMPTING >> %OUTFILE%

ECHO.
ECHO =====================================================================
ECHO Step 6: Create another 1000 rows in table: BACKUPTEST
ECHO =====================================================================
ECHO.

db2 -tvf Backup51.DDL 						>> %OUTFILE%

ECHO.
ECHO =====================================================================
ECHO Step 7: TAKE 2nd INCREMENTAL BACKUP OF BKPTEST DATABASE
ECHO         (Key 2nd step in this exercise)
ECHO =====================================================================
ECHO.

db2 backup database bkptest ONLINE incremental to c:\db2backup COMPRESS  UTIL_IMPACT_PRIORITY 50 WITHOUT PROMPTING >> %OUTFILE%

ECHO.
ECHO =====================================================================
ECHO Step 8: Create another 1000 rows in table: BACKUPTEST
ECHO =====================================================================
ECHO.

db2 -tvf Backup51.DDL 						>> %OUTFILE%

ECHO.
ECHO =====================================================================
ECHO Step 9: APPLY INCREMENTAL BACKUP (AUTOMATIC) TO BKPTEST DATABASE
ECHO         (Key 3rd step to this exercise)
ECHO =====================================================================
ECHO.

FOR /F "tokens=1" %%K in ('call Backup24.bat') do SET TIMESTAMP=%%K

ECHO STARTING INCREMENTAL RESTORE OF BKPTEST DATABASE FOR TIMESTAMP %timestamp% >> %OUTFILE%

db2 restore database bkptest incremental automatic from c:\db2backup taken at %timestamp% without prompting >> %OUTFILE%

ECHO.
ECHO =====================================================================
ECHO Step 10: Roll forward Transactions
ECHO          (Key 4th step to this exercise)
ECHO =====================================================================
ECHO.

db2 rollforward database bkptest to end of logs and complete 	>> %OUTFILE%

ECHO.
ECHO =====================================================================
ECHO Step 11: Check rows in table: BACKUPTEST
ECHO =====================================================================
ECHO.

db2 connect to bkptest						>> %OUTFILE%
db2 "select count(*) backuptest from backuptest"
db2 "select count(*) backuptest from backuptest"		>> %OUTFILE%
db2 connect reset						>> %OUTFILE%


ECHO.
ECHO ---------------------------------------------------------------------
ECHO Note: The heart of this script is "BACKUP DATABASE ONLINE
ECHO       INCREMENTAL", "RESTORE DATABASE INCREMENTAL" and "ROLLFORWARD"
ECHO       Please review these three commands carefully.
ECHO       Check the OUTPUT FILE '%OUTFILE%'
ECHO ---------------------------------------------------------------------
ECHO.