::  DB2 9.7 Admin for Experienced DBAs
::  Copyright(r) IBM Corporation
::
::  Vikram Khatri (vikram.khatri@us.ibm.com)
::

REM ------------------------------------------------------------------- 
REM Configure HADR between DB2_P and DB2_S Instances for HADB database
REM ------------------------------------------------------------------- 

TITLE HADR01.CMD - HADR setup

SET OUTFILE=%~n0_OUTPUT.TXT

@echo off
cls

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% %TIME% 
ECHO Executed by: %USERNAME% Machine: %COMPUTERNAME% On %OS% %DATE% %TIME% > %OUTFILE%
ECHO.
ECHO Configure HADR between DB2_P and DB2_S Instances for HADB database
ECHO -------------------------------------------------------------------------------
ECHO.

REM --------------------------------------------------------------------------------
REM Stop unused instances to reduce memory overhead
REM --------------------------------------------------------------------------------


set DB2INSTANCE=DB2BKP
db2stop force

set DB2INSTANCE=DB2JNK
db2stop force


REM --------------------------------------------------------------------------------
REM Remove directories and set environment
REM --------------------------------------------------------------------------------

set DB2INSTANCE=DB2

db2set db2_sqlroutine_prepopts=				>> %OUTFILE%
db2set db2_compatibility_vector=			>> %OUTFILE%
db2stop force						>> %OUTFILE%
db2start						>> %OUTFILE%

IF EXIST C:\DB2Backup\nul (
   rmdir "C:\DB2Backup" /s/q 				>> %OUTFILE%
)
IF EXIST C:\DB2HADRSharedLogArch\nul (
   rmdir "C:\DB2HADRSharedLogArch" /s/q 		>> %OUTFILE%
)
IF EXIST C:\DB2HADRData\nul (
   rmdir "C:\DB2HADRData" /s/q 				>> %OUTFILE%
)

IF NOT EXIST C:\DB2HADRData\nul (
  ECHO.
  ECHO CREATING C:\DB2HADRData directory
  ECHO.
  mkdir C:\DB2HADRData 					>> %OUTFILE%
)

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Step 1: Create DB2_P instance. (Drop the instance if it exists)
ECHO -------------------------------------------------------------------------------
ECHO.

SET INSTANCEFOUND=false
FOR /F "tokens=1" %%K in ('db2ilist') do (
   IF "%%K" EQU "DB2_P" (
      SET INSTANCEFOUND=true
      break
   )
)

IF "%INSTANCEFOUND%" EQU "true" (
   ECHO Dropping DB2_P instance
   set db2instance=DB2_P
   db2 terminate  					>> %OUTFILE%
   db2stop FORCE  					>> %OUTFILE%
   db2idrop DB2_P 					>> %OUTFILE%

   IF EXIST C:\DB2_P\nul (
     rmdir "C:\DB2_P" /s/q 				>> %OUTFILE%
   )

   IF EXIST "%ProgramFiles%\IBM\SQLLIB\DB2_P\nul" (
     rmdir "%ProgramFiles%\IBM\SQLLIB\DB2_P" /s/q 	>> %OUTFILE%
   )
)

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Creating DB2_P instance
ECHO -------------------------------------------------------------------------------
ECHO.

db2icrt DB2_P 						>> %OUTFILE%

IF NOT EXIST C:\DB2_P\nul (
  ECHO.
  ECHO CREATING C:\DB2_P directory
  ECHO.
  mkdir C:\DB2_P 					>> %OUTFILE%
)
set db2instance=DB2_P
db2 UPDATE DBM CFG USING SVCENAME DB2_DB2_P 		>> %OUTFILE%
db2set DB2COMM=TCPIP 
findstr /C:"DB2_DB2_P" "%WINDIR%\system32\drivers\etc\services"  		>> %OUTFILE%
IF ERRORLEVEL 1 (
  ECHO DB2_DB2_P not found in services file 					>> %OUTFILE%
  ECHO Creating DB2_DB2_P entry in %WINDIR%\system32\drivers\etc\services 	>> %OUTFILE%
  ECHO DB2_DB2_P      51600/tcp >> "%WINDIR%\system32\drivers\etc\services"
) else (
  ECHO %WINDIR%\system32\drivers\etc\services already contains DB2_DB2_P entry 	>> %OUTFILE%
)
findstr /C:"DB2_DB2_P_END" "%WINDIR%\system32\drivers\etc\services"  		>> %OUTFILE%
IF ERRORLEVEL 1 (
  ECHO DB2_DB2_P_END not found in services file 				>> %OUTFILE%
  ECHO Creating DB2_DB2_P_END entry in %WINDIR%\system32\drivers\etc\services 	>> %OUTFILE%
  ECHO DB2_DB2_P_END      51600/tcp >> "%WINDIR%\system32\drivers\etc\services"
) else (
  ECHO %WINDIR%\system32\drivers\etc\services already contains DB2_DB2_P_END entry >> %OUTFILE%
)
findstr /C:"DB2_HADR_1" "%WINDIR%\system32\drivers\etc\services"  		>> %OUTFILE%
IF ERRORLEVEL 1 (
  ECHO DB2_HADR_1 not found in services file 					>> %OUTFILE%
  ECHO Creating DB2_HADR_1 entry in %WINDIR%\system32\drivers\etc\services 	>> %OUTFILE%
  ECHO DB2_HADR_1      55001/tcp >> "%WINDIR%\system32\drivers\etc\services"
) else (
  ECHO %WINDIR%\system32\drivers\etc\services already contains DB2_HADR_1 entry >> %OUTFILE%
)

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Starting DB2_P instance
ECHO -------------------------------------------------------------------------------
ECHO.

db2start 					>> %OUTFILE%
db2 get instance 				>> %OUTFILE%

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Step 2: Create HADB Database in DB2_P instance.
ECHO -------------------------------------------------------------------------------
ECHO.

db2 CREATE DATABASE HADB 			>> %OUTFILE%

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Step 3: Turn on Archival Logging for HADB database in DB2_P
ECHO -------------------------------------------------------------------------------
ECHO.

IF NOT EXIST C:\DB2HADRSharedLogArch\nul (
  ECHO.
  ECHO CREATING C:\DB2HADRSharedLogArch directory
  ECHO.
  mkdir C:\DB2HADRSharedLogArch 		>> %OUTFILE%
)

ECHO Update LOGINDEXBUILD and INDEXREC parameters for HADB database in DB2_P 	>> %OUTFILE%
db2 UPDATE DB CFG FOR HADB USING LOGINDEXBUILD ON 				>> %OUTFILE%
db2 UPDATE DB CFG FOR HADB USING INDEXREC RESTART 				>> %OUTFILE%

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Turn on Archival Logging for HADB database in DB2_P 			>> %OUTFILE%
ECHO Turn on Archival Logging for HADB database in DB2_P 			
ECHO -------------------------------------------------------------------------------
ECHO.

db2 UPDATE DB CFG FOR HADB USING logarchmeth1 "DISK:C:\DB2HADRSharedLogArch" 	>> %OUTFILE%

IF NOT EXIST C:\DB2BACKUP\nul (
  ECHO.
  ECHO CREATING C:\DB2BACKUP directory
  ECHO.
  mkdir C:\DB2BACKUP >> %OUTFILE%
)

db2 terminate 							>> %OUTFILE%
ECHO Backup Database HADB to "C:\DB2Backup"
ECHO Backup Database HADB to "C:\DB2Backup" 			>> %OUTFILE%

db2  BACKUP DATABASE HADB TO "C:\DB2Backup" WITHOUT PROMPTING 	>> %OUTFILE%

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Step 4: Create DB2_S instance. (Drop the instance if it exists)
ECHO -------------------------------------------------------------------------------
ECHO.

SET INSTANCEFOUND=false
FOR /F "tokens=1" %%K in ('db2ilist') do (
   IF "%%K" EQU "DB2_S" (
      SET INSTANCEFOUND=true
      break
   )
)

IF "%INSTANCEFOUND%" EQU "true" (
   ECHO Dropping DB2_S instance
   set db2instance=DB2_S
   db2 terminate  						>> %OUTFILE%
   db2stop FORCE  						>> %OUTFILE%
   db2idrop DB2_S 						>> %OUTFILE%

   IF EXIST C:\DB2_S\nul (
     rmdir "C:\DB2_S" /s/q 					>> %OUTFILE%
   )

   IF EXIST "%ProgramFiles%\IBM\SQLLIB\DB2_S\nul" (
     rmdir "%ProgramFiles%\IBM\SQLLIB\DB2_S" /s/q 		>> %OUTFILE%
   )
)

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Creating DB2_S instance
ECHO -------------------------------------------------------------------------------
ECHO.

db2icrt DB2_S 							>> %OUTFILE%

IF NOT EXIST C:\DB2_S\nul (
  ECHO.
  ECHO CREATING C:\DB2_S directory
  ECHO.
  mkdir C:\DB2_S 						>> %OUTFILE%
)
set db2instance=DB2_S
db2 UPDATE DBM CFG USING SVCENAME DB2_DB2_S 					>> %OUTFILE%
db2set DB2COMM=TCPIP 
findstr /C:"DB2_DB2_S" "%WINDIR%\system32\drivers\etc\services" 		>> %OUTFILE%
IF ERRORLEVEL 1 (
  ECHO DB2_DB2_S not found in services file 					>> %OUTFILE%
  ECHO Creating DB2_DB2_S entry in %WINDIR%\system32\drivers\etc\services 	>> %OUTFILE%
  ECHO DB2_DB2_S      51700/tcp >> "%WINDIR%\system32\drivers\etc\services"
) else (
  ECHO %WINDIR%\system32\drivers\etc\services already contains DB2_DB2_S entry 	>> %OUTFILE%
)
findstr /C:"DB2_DB2_S_END" "%WINDIR%\system32\drivers\etc\services"  		>> %OUTFILE%
IF ERRORLEVEL 1 (
  ECHO DB2_DB2_S_END not found in services file 				>> %OUTFILE%
  ECHO Creating DB2_DB2_S_END entry in %WINDIR%\system32\drivers\etc\services 	>> %OUTFILE%
  ECHO DB2_DB2_S_END      51700/tcp >> "%WINDIR%\system32\drivers\etc\services"
) else (
  ECHO %WINDIR%\system32\drivers\etc\services already contains DB2_DB2_S_END entry >> %OUTFILE%
)
findstr /C:"DB2_HADR_2" "%WINDIR%\system32\drivers\etc\services"  		>> %OUTFILE%
IF ERRORLEVEL 1 (
  ECHO DB2_HADR_2 not found in services file 					>> %OUTFILE%
  ECHO Creating DB2_HADR_2 entry in %WINDIR%\system32\drivers\etc\services 	>> %OUTFILE%
  ECHO DB2_HADR_2      55002/tcp >> "%WINDIR%\system32\drivers\etc\services"
) else (
  ECHO %WINDIR%\system32\drivers\etc\services already contains DB2_HADR_2 entry >> %OUTFILE%
)
ECHO Starting DB2_S instance
db2start 						>> %OUTFILE%
db2 get instance 					>> %OUTFILE%

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Step 5: Restore HADB Database in DB2_S instance.
ECHO -------------------------------------------------------------------------------
ECHO.

ECHO Restoring HADB database from backup in DB2_S instance

db2 RESTORE DB HADB FROM C:\DB2BACKUP REPLACE HISTORY FILE WITHOUT PROMPTING 	>> %OUTFILE%

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Step 6: Catalog Node and Databases in DB2_P and DB2_S instances
ECHO -------------------------------------------------------------------------------
ECHO.

set db2instance=DB2_P
db2 CATALOG LOCAL NODE DB2_S INSTANCE DB2_S 		>> %OUTFILE%
db2 CATALOG DB HADB AS HADBP 				>> %OUTFILE%
db2 CATALOG DB HADB AS HADBS AT NODE DB2_S 		>> %OUTFILE%

set db2instance=DB2_S
db2 CATALOG LOCAL NODE DB2_P INSTANCE DB2_P 		>> %OUTFILE%
db2 CATALOG DB HADB AS HADBS 				>> %OUTFILE%
db2 CATALOG DB HADB AS HADBP AT NODE DB2_P 		>> %OUTFILE%
db2 terminate 						>> %OUTFILE%

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Step 7: Configure Client Re-route in DB2_P/DB2_S instances for HADB database
ECHO -------------------------------------------------------------------------------
ECHO.

set db2instance=DB2_P
db2 UPDATE ALTERNATE SERVER FOR DATABASE HADBS USING HOSTNAME %COMPUTERNAME% PORT 51700 >> %OUTFILE%
db2 terminate 						>> %OUTFILE%

set db2instance=DB2_S
db2 UPDATE ALTERNATE SERVER FOR DATABASE HADBP USING HOSTNAME %COMPUTERNAME% PORT 51600 >> %OUTFILE%
db2 terminate 						>> %OUTFILE%

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Step 8: Configure HADR in DB2_P instance for database HADB
ECHO -------------------------------------------------------------------------------
ECHO.

set db2instance=DB2_P
db2 UPDATE DB CFG FOR HADB USING HADR_LOCAL_HOST %COMPUTERNAME% HADR_LOCAL_SVC DB2_HADR_1 HADR_REMOTE_HOST %COMPUTERNAME% HADR_REMOTE_SVC DB2_HADR_2 HADR_REMOTE_INST DB2_S HADR_SYNCMODE SYNC HADR_TIMEOUT 120 >> %OUTFILE%

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Step 9: Configure HADR in DB2_S instance for database HADB
ECHO -------------------------------------------------------------------------------
ECHO.

set db2instance=DB2_S
db2 UPDATE DB CFG FOR HADB USING HADR_LOCAL_HOST %COMPUTERNAME% HADR_LOCAL_SVC DB2_HADR_2 HADR_REMOTE_HOST %COMPUTERNAME% HADR_REMOTE_SVC DB2_HADR_1 HADR_REMOTE_INST DB2_P HADR_SYNCMODE SYNC HADR_TIMEOUT 120 >> %OUTFILE%
db2 terminate 						>> %OUTFILE%

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Step 10: Start HADR on DB2_S in Standby mode
ECHO -------------------------------------------------------------------------------
ECHO.

set db2instance=DB2_S
db2 START HADR ON DATABASE HADB AS STANDBY 		>> %OUTFILE%

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Step 11: Start HADR on DB2_P in Primary mode
ECHO -------------------------------------------------------------------------------
ECHO.

set db2instance=DB2_P
db2 START HADR ON DATABASE HADB AS PRIMARY 		>> %OUTFILE%

ECHO.
ECHO -------------------------------------------------------------------------------
ECHO Step 12: Catalog node and database in DB2 Instance
ECHO -------------------------------------------------------------------------------
ECHO.

set DB2INSTANCE=DB2
db2 CATALOG LOCAL NODE DB2_P INSTANCE DB2_P 		>> %OUTFILE%
db2 CATALOG DB HADB AS HADBP AT NODE  DB2_P 		>> %OUTFILE%
db2 CATALOG LOCAL NODE DB2_S INSTANCE DB2_S 		>> %OUTFILE%
db2 CATALOG DB HADB AS HADBS AT NODE  DB2_S 		>> %OUTFILE%
db2 terminate 						>> %OUTFILE%

