-- ------------------------------------------------------------------------------
-- DB2 POT - 14HADR
-- ------------------------------------------------------------------------------
-- Purpose: 1. Create HATABLE table in HADB database on Primary database server
--             This table will propagate to STANDBY Database through DB2 Logs
--          2. Create an index on this table in COPY=YES mode
--          3. Create a HALOAD table
--          4. Load data in HALOAD table using COPY=YES mode
--          5. Create an index on this table
-- ------------------------------------------------------------------------------

Connect to hadbp;

DROP TABLE hatable;

CREATE TABLE hatable
(
   hatable_id    INTEGER NOT NULL GENERATED ALWAYS AS IDENTITY (START WITH 100000, INCREMENT BY 5),
   SSN            CHAR(11) NOT NULL,
   FIRST_NAME     VARCHAR(20) NOT NULL,
   LAST_NAME      VARCHAR(20) NOT NULL,
   job_code       CHAR(4) NOT NULL,
   dept           SMALLINT NOT NULL,
   salary         DECIMAL(12,2) NOT NULL,
   DOB            DATE NOT NULL WITH DEFAULT,
   CONSTRAINT pk_hatable PRIMARY KEY (hatable_id)
);


-- Insert 25000 rows

INSERT INTO hatable (SSN,FIRST_NAME,LAST_NAME,job_code,dept,salary,DOB)
WITH temp1 (s1,r1,r2,r3,r4) AS
(VALUES (0
,RAND(2)
,RAND()+(RAND()/1E5)
,RAND()* RAND()
,RAND()* RAND()* RAND())
UNION ALL
SELECT s1 + 1
,RAND()
,RAND()+(RAND()/1E5)
,RAND()* RAND()
,RAND()* RAND()* RAND()
FROM temp1
WHERE s1 < 24999
)
SELECT SUBSTR(DIGITS(INT(r2*988+10)),8) ||'-'||
       SUBSTR(DIGITS(INT(r1*88+10)),9) || '-' ||
       TRANSLATE(SUBSTR(DIGITS(s1),7),'9873450126','0123456789'),
       CHR(INT(r1*26+65))|| CHR(INT(r2*26+97))|| CHR(INT(r3*26+97))||CHR(INT(r4*26+97))|| CHR(INT(r3*10+97))|| CHR(INT(r3*11+97)),
       CHR(INT(r2*26+65))||TRANSLATE(CHAR(INT(r2*1E7)),'aaeeiibmty','0123456789'),       
       CASE
         WHEN INT(r4*9) > 7 THEN 'MGR'
         WHEN INT(r4*9) > 5 THEN 'SUPR'
         WHEN INT(r4*9) > 3 THEN 'PGMR'
         WHEN INT(R4*9) > 1 THEN 'SEC'
         ELSE 'WKR'
       END,
       INT(r3*98+1),
       DECIMAL(r4*99999,7,2),
       DATE('1930-01-01') + INT(50-(r4*50)) YEARS + INT(r4*11) MONTHS + INT(r4*27) DAYS
FROM temp1;

-- Insert 25000 rows

INSERT INTO hatable (SSN,FIRST_NAME,LAST_NAME,job_code,dept,salary,DOB)
WITH temp1 (s1,r1,r2,r3,r4) AS
(VALUES (0
,RAND(2)
,RAND()+(RAND()/1E5)
,RAND()* RAND()
,RAND()* RAND()* RAND())
UNION ALL
SELECT s1 + 1
,RAND()
,RAND()+(RAND()/1E5)
,RAND()* RAND()
,RAND()* RAND()* RAND()
FROM temp1
WHERE s1 < 24999
)
SELECT SUBSTR(DIGITS(INT(r2*988+10)),8) ||'-'||
       SUBSTR(DIGITS(INT(r1*88+10)),9) || '-' ||
       TRANSLATE(SUBSTR(DIGITS(s1),7),'9873450126','0123456789'),
       CHR(INT(r1*26+65))|| CHR(INT(r2*26+97))|| CHR(INT(r3*26+97))||CHR(INT(r4*26+97))|| CHR(INT(r3*10+97))|| CHR(INT(r3*11+97)),
       CHR(INT(r2*26+65))||TRANSLATE(CHAR(INT(r2*1E7)),'aaeeiibmty','0123456789'),       
       CASE
         WHEN INT(r4*9) > 7 THEN 'MGR'
         WHEN INT(r4*9) > 5 THEN 'SUPR'
         WHEN INT(r4*9) > 3 THEN 'PGMR'
         WHEN INT(R4*9) > 1 THEN 'SEC'
         ELSE 'WKR'
       END,
       INT(r3*98+1),
       DECIMAL(r4*99999,7,2),
       DATE('1930-01-01') + INT(50-(r4*50)) YEARS + INT(r4*11) MONTHS + INT(r4*27) DAYS
FROM temp1;

CREATE INDEX UIX_01_hatable ON hatable 
  	(SSN ASC);

drop table haload;

CREATE TABLE haload  (
  	  ST_PARTKEY INTEGER NOT NULL , 
  	  ST_SUPPKEY INTEGER NOT NULL , 
  	  ST_AVAILQTY INTEGER NOT NULL , 
  	  ST_SUPPLYCOST DOUBLE NOT NULL);
      
CREATE INDEX PK_haload ON haload 
  	(ST_PARTKEY ASC);
   
CREATE UNIQUE INDEX UIX_01_haload ON haload  
  	(ST_PARTKEY ASC,
  	 ST_SUPPKEY ASC);

CREATE INDEX IX_01_haload ON haload   
  	(ST_SUPPKEY ASC);

LOAD FROM "C:\POT_DB2\14HADR\HADR05.DAT" OF DEL MODIFIED BY COLDEL|  MESSAGES "C:\POT_DB2\14HADR\HADR05.MSG" REPLACE INTO HALOAD STATISTICS USE PROFILE COPY YES TO "C:\DB2HADRData" INDEXING MODE AUTOSELECT LOCK WITH FORCE;

Connect reset;
terminate;
