  
---------------------------------------------------------------
-- CREATE A WLM ENVIRONMENT showing new DB2 9.7 features
---------------------------------------------------------------

---------------------------------------------------------------
-- set all existing work to default workload
---------------------------------------------------------------

SET WORKLOAD TO SYSDEFAULTADMWORKLOAD;


---------------------------------------------------------------
-- create service classes 
---------------------------------------------------------------

-- Note BUFFERPOOL PRIORITY below - This is a new DB2 9.7 feature

CREATE 	SERVICE CLASS "CLP_Serv_Admin" 
	PREFETCH   PRIORITY HIGH
	AGENT 	   PRIORITY 0 
	BUFFERPOOL PRIORITY HIGH
	DISABLE;

CREATE 	SERVICE CLASS "CLP_Serv_Admin_HI"
	UNDER "CLP_Serv_Admin" 
	PREFETCH   PRIORITY HIGH
	AGENT 	   PRIORITY 6 
	BUFFERPOOL PRIORITY HIGH
	DISABLE;

CREATE  SERVICE CLASS "CLP_Serv_Admin_MED"
	UNDER "CLP_Serv_Admin" 
	PREFETCH   PRIORITY MEDIUM
	AGENT 	   PRIORITY 2 
	BUFFERPOOL PRIORITY MEDIUM
	DISABLE;

CREATE 	SERVICE CLASS "CLP_Serv_User" 
	PREFETCH   PRIORITY LOW
	AGENT 	   PRIORITY -5 
	BUFFERPOOL PRIORITY LOW
	DISABLE;


---------------------------------------------------------------
-- create workloads and assign to service classes
---------------------------------------------------------------

-- Note AGGREGATE acitivity on a workloads is a new DB2 9.7 feature

CREATE 	WORKLOAD "CLP_Workload_Admin" 
	APPLNAME('db2bp.exe')
	CURRENT CLIENT_USERID('db2cobra')
	DISABLE	
	SERVICE CLASS "CLP_Serv_Admin" 
	COLLECT ACTIVITY METRICS
	COLLECT ACTIVITY DATA ON ALL DATABASE PARTITIONS
	COLLECT AGGREGATE ACTIVITY DATA BASE
	POSITION AT 1;


-- Note CLIENT_USER wildcard below - This is a new DB2 9.7 feature

CREATE 	WORKLOAD "CLP_Workload_User1"
	APPLNAME('db2bp.exe')
	CURRENT CLIENT_USERID('db2user*')
	DISABLE	
	SERVICE CLASS "CLP_Serv_User"
	COLLECT ACTIVITY METRICS
	COLLECT ACTIVITY DATA ON ALL DATABASE PARTITIONS
	COLLECT AGGREGATE ACTIVITY DATA BASE
	POSITION AT 2;


-- Note ADDRESS connection attribute below - This is a new DB2 9.7 feature

CREATE  WORKLOAD "IPADDR" 
	ADDRESS('9.26.53.111') 
	DISABLE;


---------------------------------------------------------------
-- create thresholds (both database and workload types)
---------------------------------------------------------------

CREATE 	THRESHOLD "MAX_Activities"
	FOR WORKLOAD "CLP_Workload_User1" ACTIVITIES 
	ENFORCEMENT WORKLOAD OCCURRENCE 
	WHEN CONCURRENTWORKLOADACTIVITIES > 5 
	STOP EXECUTION;

CREATE 	THRESHOLD "Report_Long_Queries" 
	FOR DATABASE ACTIVITIES 
	ENFORCEMENT DATABASE 
	WHEN ACTIVITYTOTALTIME > 10 MINUTES 
     		COLLECT ACTIVITY DATA WITH DETAILS AND VALUES 
	CONTINUE;

-- Note DATABASE ACTIVITIES with CPUTIME below - This is a new DB2 9.7 feature

CREATE 	THRESHOLD "Report_CPU_Hogs" 
	FOR DATABASE ACTIVITIES 
	ENFORCEMENT DATABASE PARTITION 
	WHEN CPUTIME > 10 SECONDS 
     		COLLECT ACTIVITY DATA WITH DETAILS AND VALUES 
	CONTINUE;


---------------------------------------------------------------
-- create work class sets
---------------------------------------------------------------

CREATE 	WORK CLASS SET "DML_Usage"
       (WORK CLASS "Read_Work"  WORK TYPE read,
	WORK CLASS "Write_Work" WORK TYPE write);


---------------------------------------------------------------
-- create work action sets
---------------------------------------------------------------

CREATE 	WORK ACTION SET "Admin_Actions" FOR SERVICE CLASS "CLP_Serv_Admin"
	USING WORK CLASS SET "DML_Usage"
	(WORK ACTION "Map_Writes" ON WORK CLASS "Write_Work"  
		MAP ACTIVITY TO "CLP_Serv_Admin_HI",
   	 WORK ACTION "Map_Reads"  ON WORK CLASS "Read_Work"   
		MAP ACTIVITY TO "CLP_Serv_Admin_MED");


---------------------------------------------------------------
-- grant usage of workloads
---------------------------------------------------------------

GRANT 	USAGE ON WORKLOAD "CLP_Workload_Admin" TO PUBLIC;
GRANT 	USAGE ON WORKLOAD "CLP_Workload_User1" TO PUBLIC;
GRANT 	USAGE ON WORKLOAD "IPADDR" 	       TO PUBLIC;


---------------------------------------------------------------
-- enable the service classes and workloads
---------------------------------------------------------------

ALTER 	SERVICE CLASS "CLP_Serv_Admin"     ENABLE;
ALTER 	SERVICE CLASS "CLP_Serv_Admin_HI"  UNDER "CLP_Serv_Admin" ENABLE;
ALTER 	SERVICE CLASS "CLP_Serv_Admin_MED" UNDER "CLP_Serv_Admin" ENABLE;
ALTER 	SERVICE CLASS "CLP_Serv_User"      ENABLE;

ALTER 	WORKLOAD "CLP_Workload_Admin" ENABLE;
ALTER 	WORKLOAD "CLP_Workload_User1" ENABLE;
ALTER 	WORKLOAD "IPADDR" 	      ENABLE;


---------------------------------------------------------------
-- start using the new WLM environment
---------------------------------------------------------------
COMMIT;

SET 	WORKLOAD TO AUTOMATIC;


---------------------------------------------------------------
-- end of WLM setup script
---------------------------------------------------------------


