
-- --------------------------------------------------------------------- 
-- WLM Monitoring Script Examples
-- --------------------------------------------------------------------- 

-- Use this to connect if you haven't already done so...
--
CONNECT TO SAMPLE USER db2cobra USING db2cobra;


-- --------------------------------------------------------------------- 
-- IN MEMORY FUNCTIONS - These show in-memory statistics
-- --------------------------------------------------------------------- 

-- --------------------------------------------------------------------- 
-- #1 Workload -> service class occurences 
-- --------------------------------------------------------------------- 
SELECT 	SUBSTR(WORKLOAD_NAME,1,22) AS WORKLOAD_NAME,
	SUBSTR(SERVICE_SUPERCLASS_NAME,1,19) AS SUPERCLASS_NAME,
	SUBSTR(SYSTEM_AUTH_ID,1,10) AS SYS_AUTH_ID,
	SUBSTR(APPLICATION_NAME,1,15) AS APP_NAME,
       	SUBSTR(CHAR(APPLICATION_HANDLE),1,7) AS APP_HANDLE,
       	SUBSTR(CHAR(WORKLOAD_OCCURRENCE_ID),1,6) AS WLOCCUR_ID
FROM 	TABLE(WLM_GET_SERVICE_CLASS_WORKLOAD_OCCURRENCES_V97
        (CAST(NULL AS VARCHAR(128)), CAST(NULL AS VARCHAR(128)), -2)) AS SC_INFO
ORDER 	BY SUPERCLASS_NAME, APP_NAME, WORKLOAD_NAME, WLOCCUR_ID;


-- --------------------------------------------------------------------- 
-- #2 Service class activity counts - In-memory statistics function
-- --------------------------------------------------------------------- 
SELECT VARCHAR( SERVICE_SUPERCLASS_NAME, 30) SUPERCLASS,
       VARCHAR( SERVICE_SUBCLASS_NAME, 30) SUBCLASS,   
       COORD_ACT_COMPLETED_TOTAL AS TOTAL_ACTIVITIES_COMPLETED,
       COORD_ACT_ABORTED_TOTAL AS TOTAL_ACTIVITIES_ABORTED,
       ACT_REMAPPED_IN AS ACTIVITIES_REMAPPED_IN,
       ACT_REMAPPED_OUT AS ACTIVITIES_REMAPPED_OUT
FROM TABLE(WLM_GET_SERVICE_SUBCLASS_STATS_V97('','',-1)) AS SC_COUNTS;


-- --------------------------------------------------------------------- 
-- #3 Work Action Set Activity Count - In-memory statistics function
-- --------------------------------------------------------------------- 
SELECT SUBSTR(WORK_ACTION_SET_NAME, 1, 12) AS WORK_ACTION_SET_NAME,
         SUBSTR(WORK_CLASS_NAME, 1, 12) AS WORK_CLASS_NAME,
         LAST_RESET,
         SUBSTR(CHAR(ACT_TOTAL), 1, 10) AS TOTAL_ACTIVITIES
FROM TABLE(WLM_GET_WORK_ACTION_SET_STATS('', -2)) AS WASSTATS
ORDER BY WORK_ACTION_SET_NAME, WORK_CLASS_NAME;



-- ---------------------------------------------------------------------
-- #4 Long query to test activity remapping  
--    (make sure you run the FLUSH PACKAGE CACHE DYNAMIC statement too!)
-- --------------------------------------------------------------------- 
FLUSH PACKAGE CACHE DYNAMIC;
SELECT 	WLM_SAMPLE_TABLE_ID, FIRST_NAME||' '||LAST_NAME AS NEWNAME, SALARY, JOB_CODE, 
	sum(SALARY) over() AS sum_sal, avg(SALARY) over() AS avg_sal, 
	min(SALARY) over() AS min_sal, max(SALARY) over() AS max_sal, count(*) over() AS rows 
FROM 	DB2COBRA.WLM_SAMPLE_TABLE 
WHERE   SSN LIKE '%-%' AND
	FIRST_NAME NOT LIKE '%Sheniqua%' AND
	JOB_CODE NOT IN (SELECT DISTINCT SUBSTR(FIRST_NAME,1,4) FROM DB2COBRA.WLM_SAMPLE_TABLE)	
GROUP   BY WLM_SAMPLE_TABLE_ID, FIRST_NAME||' '||LAST_NAME, SALARY, JOB_CODE
ORDER 	BY JOB_CODE, WLM_SAMPLE_TABLE_ID, NEWNAME, SALARY, JOB_CODE, AVG_SAL, MAX_SAL
FOR FETCH ONLY;

-- --------------------------------------------------------------------- 
-- Send stats to event monitors & reset in-memory statistics to 0.
-- --------------------------------------------------------------------- 
CALL WLM_COLLECT_STATS();


-- --------------------------------------------------------------------- 
-- Event Monitor table selects - these keep a history of WLM statistics
-- --------------------------------------------------------------------- 

-- --------------------------------------------------------------------- 
-- #5.  Workload event monitor summary table select
-- --------------------------------------------------------------------- 
SELECT 	SUBSTR(WORKLOAD_NAME,1,25) WORKLOAD_NAME, 
	SUM(WLO_COMPLETED_TOTAL) AS COMPLETED_WORKLOADS, 
	SUM(COORD_ACT_COMPLETED_TOTAL) AS COMPLETED_ACTIVITIES 
FROM 	DB2COBRA.WLSTATS_DB2STATISTICS
GROUP	BY WORKLOAD_NAME
ORDER 	BY WORKLOAD_NAME;


-- --------------------------------------------------------------------- 
-- #6.  Workload aggregate event monitor summary table select
-- --------------------------------------------------------------------- 
SELECT 	SUBSTR(WORKLOAD_NAME,1,25) WORKLOAD_NAME, 
	SUM(COORD_ACT_LIFETIME_TOP) COORD_ACT_LIFETIME_TOP,
	SUM(COORD_ACT_LIFETIME_AVG) COORD_ACT_LIFETIME_AVG
FROM	DB2COBRA.WLSTATS_DB2STATISTICS
WHERE	COORD_ACT_LIFETIME_TOP <> -1
GROUP	BY WORKLOAD_NAME
ORDER 	BY WORKLOAD_NAME ASC, COORD_ACT_LIFETIME_TOP DESC;


-- --------------------------------------------------------------------- 
-- #7.  Service Class event monitor summary table select
-- --------------------------------------------------------------------- 
SELECT 	SUBSTR(SERVICE_SUPERCLASS_NAME,1,30) SUPERCLASS_NAME, 
	SUBSTR(SERVICE_SUBCLASS_NAME,1,25) SUBCLASS_NAME,
	SUM(COORD_ACT_COMPLETED_TOTAL) AS COMPLETED_ACTIVITIES 
FROM 	DB2COBRA.SCSTATS_DB2STATISTICS
GROUP	BY SERVICE_SUPERCLASS_NAME, SERVICE_SUBCLASS_NAME
ORDER 	BY SERVICE_SUBCLASS_NAME, SERVICE_SUBCLASS_NAME;


-- --------------------------------------------------------------------- 
-- #8.  Work Action Set event monitor summary table select
-- --------------------------------------------------------------------- 
SELECT 	SUBSTR(WORK_ACTION_SET_NAME,1,20) WORK_ACTION_SET_NAME, 
	SUBSTR(WORK_CLASS_NAME,1,20) WORK_CLASS_NAME, 
	SUM(ACT_TOTAL) AS TOTAL_ACTIVITIES
FROM	DB2COBRA.WCSTATS_DB2STATISTICS
GROUP 	BY WORK_ACTION_SET_NAME, WORK_CLASS_NAME
ORDER	BY WORK_ACTION_SET_NAME, WORK_CLASS_NAME;


-- --------------------------------------------------------------------- 
-- #9.  Threshold violations event monitor summary table select
-- --------------------------------------------------------------------- 
SELECT 	SUBSTR(T2.THRESHOLDNAME,1,35) AS THRESH_NAME, 
	SUBSTR(S1.SERVICECLASSNAME,1,30) AS SOURCE_SERVICE_CLASS, 
	SUBSTR(S2.SERVICECLASSNAME,1,30) AS TARGET_SERVICE_CLASS, 
	T1.THRESHOLD_ACTION AS THRESH_ACTION, 
	SUBSTR(T1.THRESHOLD_PREDICATE,1,20) AS PREDICATE, 
	T1.THRESHOLD_MAXVALUE,
	T1.TIME_OF_VIOLATION
FROM 	(DB2COBRA.THRESHOLDVIOLATIONS_DB2THRESHOLDVIOLATIONS T1
	LEFT JOIN SYSCAT.THRESHOLDS T2
	     ON T1.THRESHOLDID = T2.THRESHOLDID)
	LEFT JOIN SYSCAT.SERVICECLASSES S1
	     ON T1.SOURCE_SERVICE_CLASS_ID = S1.SERVICECLASSID
	LEFT JOIN SYSCAT.SERVICECLASSES S2
	     ON T1.DESTINATION_SERVICE_CLASS_ID = S2.SERVICECLASSID;


-- ---------------------------------------------------------------------
-- SELECT * in-memory functions to play with on your own...  
-- --------------------------------------------------------------------- 
SELECT * FROM TABLE(WLM_GET_SERVICE_CLASS_WORKLOAD_OCCURRENCES_V97(CAST(NULL AS VARCHAR(128)), CAST(NULL AS VARCHAR(128)), -2)) AS SCINFO;

SELECT * FROM TABLE(WLM_GET_WORKLOAD_STATS_V97(CAST(NULL AS VARCHAR(128)), -2)) AS WL_STATS;

SELECT * FROM TABLE(WLM_GET_SERVICE_SUBCLASS_STATS_V97(CAST(NULL AS VARCHAR(128)), CAST(NULL AS VARCHAR(128)), -2)) AS SC_TSATS;

SELECT * FROM TABLE(WLM_GET_WORK_ACTION_SET_STATS('', -2)) AS WASSTATS;


-- --------------------------------------------------------------------- 
-- END - WLM Monitoring Script Examples
-- --------------------------------------------------------------------- 
